Class: ModernTreasury::AccountCollectionFlowCreateRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/modern_treasury/models/account_collection_flow_create_request.rb

Overview

AccountCollectionFlowCreateRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(counterparty_id:, payment_types:, additional_properties: nil) ⇒ AccountCollectionFlowCreateRequest

Returns a new instance of AccountCollectionFlowCreateRequest.



38
39
40
41
42
43
44
45
# File 'lib/modern_treasury/models/account_collection_flow_create_request.rb', line 38

def initialize(counterparty_id:, payment_types:, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @counterparty_id = counterparty_id
  @payment_types = payment_types
  @additional_properties = additional_properties
end

Instance Attribute Details

#counterparty_idUUID | String

Required.

Returns:

  • (UUID | String)


14
15
16
# File 'lib/modern_treasury/models/account_collection_flow_create_request.rb', line 14

def counterparty_id
  @counterparty_id
end

#payment_typesArray[String]

Required.

Returns:

  • (Array[String])


18
19
20
# File 'lib/modern_treasury/models/account_collection_flow_create_request.rb', line 18

def payment_types
  @payment_types
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/modern_treasury/models/account_collection_flow_create_request.rb', line 48

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  counterparty_id =
    hash.key?('counterparty_id') ? hash['counterparty_id'] : nil
  payment_types = hash.key?('payment_types') ? hash['payment_types'] : nil

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AccountCollectionFlowCreateRequest.new(counterparty_id: counterparty_id,
                                         payment_types: payment_types,
                                         additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



21
22
23
24
25
26
# File 'lib/modern_treasury/models/account_collection_flow_create_request.rb', line 21

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['counterparty_id'] = 'counterparty_id'
  @_hash['payment_types'] = 'payment_types'
  @_hash
end

.nullablesObject

An array for nullable fields



34
35
36
# File 'lib/modern_treasury/models/account_collection_flow_create_request.rb', line 34

def self.nullables
  []
end

.optionalsObject

An array for optional fields



29
30
31
# File 'lib/modern_treasury/models/account_collection_flow_create_request.rb', line 29

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



77
78
79
80
81
# File 'lib/modern_treasury/models/account_collection_flow_create_request.rb', line 77

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} counterparty_id: #{@counterparty_id.inspect}, payment_types:"\
  " #{@payment_types.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



70
71
72
73
74
# File 'lib/modern_treasury/models/account_collection_flow_create_request.rb', line 70

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} counterparty_id: #{@counterparty_id}, payment_types: #{@payment_types},"\
  " additional_properties: #{@additional_properties}>"
end