Class: ModernTreasury::AccountCollectionFlowUpdateRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/modern_treasury/models/account_collection_flow_update_request.rb

Overview

AccountCollectionFlowUpdateRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(additional_properties: nil) ⇒ AccountCollectionFlowUpdateRequest

Returns a new instance of AccountCollectionFlowUpdateRequest.



34
35
36
37
38
39
40
# File 'lib/modern_treasury/models/account_collection_flow_update_request.rb', line 34

def initialize(additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @status = 'cancelled'
  @additional_properties = additional_properties
end

Instance Attribute Details

#statusString (readonly)

Required. The updated status of the account collection flow. Can only be used to mark a flow as ‘cancelled`.

Returns:

  • (String)


15
16
17
# File 'lib/modern_treasury/models/account_collection_flow_update_request.rb', line 15

def status
  @status
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/modern_treasury/models/account_collection_flow_update_request.rb', line 43

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.


  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AccountCollectionFlowUpdateRequest.new(additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



18
19
20
21
22
# File 'lib/modern_treasury/models/account_collection_flow_update_request.rb', line 18

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['status'] = 'status'
  @_hash
end

.nullablesObject

An array for nullable fields



30
31
32
# File 'lib/modern_treasury/models/account_collection_flow_update_request.rb', line 30

def self.nullables
  []
end

.optionalsObject

An array for optional fields



25
26
27
# File 'lib/modern_treasury/models/account_collection_flow_update_request.rb', line 25

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



67
68
69
70
71
# File 'lib/modern_treasury/models/account_collection_flow_update_request.rb', line 67

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} status: #{@status.inspect}, additional_properties:"\
  " #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



61
62
63
64
# File 'lib/modern_treasury/models/account_collection_flow_update_request.rb', line 61

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} status: #{@status}, additional_properties: #{@additional_properties}>"
end