Class: ModernTreasury::AccountDetail

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/modern_treasury/models/account_detail.rb

Overview

AccountDetail Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id:, object:, live_mode:, created_at:, updated_at:, discarded_at:, account_number_type:, account_number_safe:, account_number: SKIP) ⇒ AccountDetail

Returns a new instance of AccountDetail.



83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/modern_treasury/models/account_detail.rb', line 83

def initialize(id:, object:, live_mode:, created_at:, updated_at:,
               discarded_at:, account_number_type:, account_number_safe:,
               account_number: SKIP)
  @id = id
  @object = object
  @live_mode = live_mode
  @created_at = created_at
  @updated_at = updated_at
  @discarded_at = discarded_at
  @account_number =  unless  == SKIP
  @account_number_type = 
  @account_number_safe = 
end

Instance Attribute Details

#account_numberString

The account number for the bank account.

Returns:

  • (String)


43
44
45
# File 'lib/modern_treasury/models/account_detail.rb', line 43

def 
  @account_number
end

#account_number_safeString

The last 4 digits of the account_number.

Returns:

  • (String)


52
53
54
# File 'lib/modern_treasury/models/account_detail.rb', line 52

def 
  @account_number_safe
end

#account_number_typeAccountNumberType

One of ‘iban`, `clabe`, `wallet_address`, or `other`. Use `other` if the bank account number is in a generic format.

Returns:



48
49
50
# File 'lib/modern_treasury/models/account_detail.rb', line 48

def 
  @account_number_type
end

#created_atDateTime

This field will be true if this object exists in the live environment or false if it exists in the test environment.

Returns:

  • (DateTime)


29
30
31
# File 'lib/modern_treasury/models/account_detail.rb', line 29

def created_at
  @created_at
end

#discarded_atDateTime

This field will be true if this object exists in the live environment or false if it exists in the test environment.

Returns:

  • (DateTime)


39
40
41
# File 'lib/modern_treasury/models/account_detail.rb', line 39

def discarded_at
  @discarded_at
end

#idUUID | String

TODO: Write general description for this method

Returns:

  • (UUID | String)


15
16
17
# File 'lib/modern_treasury/models/account_detail.rb', line 15

def id
  @id
end

#live_modeTrueClass | FalseClass

This field will be true if this object exists in the live environment or false if it exists in the test environment.

Returns:

  • (TrueClass | FalseClass)


24
25
26
# File 'lib/modern_treasury/models/account_detail.rb', line 24

def live_mode
  @live_mode
end

#objectString

TODO: Write general description for this method

Returns:

  • (String)


19
20
21
# File 'lib/modern_treasury/models/account_detail.rb', line 19

def object
  @object
end

#updated_atDateTime

This field will be true if this object exists in the live environment or false if it exists in the test environment.

Returns:

  • (DateTime)


34
35
36
# File 'lib/modern_treasury/models/account_detail.rb', line 34

def updated_at
  @updated_at
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
# File 'lib/modern_treasury/models/account_detail.rb', line 98

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : nil
  object = hash.key?('object') ? hash['object'] : nil
  live_mode = hash.key?('live_mode') ? hash['live_mode'] : nil
  created_at = if hash.key?('created_at')
                 (DateTimeHelper.from_rfc3339(hash['created_at']) if hash['created_at'])
               end
  updated_at = if hash.key?('updated_at')
                 (DateTimeHelper.from_rfc3339(hash['updated_at']) if hash['updated_at'])
               end
  discarded_at = if hash.key?('discarded_at')
                   (DateTimeHelper.from_rfc3339(hash['discarded_at']) if hash['discarded_at'])
                 end
   =
    hash.key?('account_number_type') ? hash['account_number_type'] : nil
   =
    hash.key?('account_number_safe') ? hash['account_number_safe'] : nil
   =
    hash.key?('account_number') ? hash['account_number'] : SKIP

  # Create object from extracted values.
  AccountDetail.new(id: id,
                    object: object,
                    live_mode: live_mode,
                    created_at: created_at,
                    updated_at: updated_at,
                    discarded_at: discarded_at,
                    account_number_type: ,
                    account_number_safe: ,
                    account_number: )
end

.namesObject

A mapping from model property names to API property names.



55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/modern_treasury/models/account_detail.rb', line 55

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id'] = 'id'
  @_hash['object'] = 'object'
  @_hash['live_mode'] = 'live_mode'
  @_hash['created_at'] = 'created_at'
  @_hash['updated_at'] = 'updated_at'
  @_hash['discarded_at'] = 'discarded_at'
  @_hash['account_number'] = 'account_number'
  @_hash['account_number_type'] = 'account_number_type'
  @_hash['account_number_safe'] = 'account_number_safe'
  @_hash
end

.nullablesObject

An array for nullable fields



77
78
79
80
81
# File 'lib/modern_treasury/models/account_detail.rb', line 77

def self.nullables
  %w[
    discarded_at
  ]
end

.optionalsObject

An array for optional fields



70
71
72
73
74
# File 'lib/modern_treasury/models/account_detail.rb', line 70

def self.optionals
  %w[
    account_number
  ]
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (AccountDetail | Hash)

    value against the validation is performed.



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/modern_treasury/models/account_detail.rb', line 147

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.id,
                            ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.object,
                              ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.live_mode,
                              ->(val) { val.instance_of? TrueClass or val.instance_of? FalseClass }) and
        APIHelper.valid_type?(value.created_at,
                              ->(val) { val.instance_of? DateTime }) and
        APIHelper.valid_type?(value.updated_at,
                              ->(val) { val.instance_of? DateTime }) and
        APIHelper.valid_type?(value.discarded_at,
                              ->(val) { val.instance_of? DateTime }) and
        APIHelper.valid_type?(value.,
                              ->(val) { AccountNumberType.validate(val) }) and
        APIHelper.valid_type?(value.,
                              ->(val) { val.instance_of? String })
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['id'],
                          ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['object'],
                            ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['live_mode'],
                            ->(val) { val.instance_of? TrueClass or val.instance_of? FalseClass }) and
      APIHelper.valid_type?(value['created_at'],
                            ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['updated_at'],
                            ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['discarded_at'],
                            ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['account_number_type'],
                            ->(val) { AccountNumberType.validate(val) }) and
      APIHelper.valid_type?(value['account_number_safe'],
                            ->(val) { val.instance_of? String })
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



201
202
203
204
205
206
207
208
# File 'lib/modern_treasury/models/account_detail.rb', line 201

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id.inspect}, object: #{@object.inspect}, live_mode:"\
  " #{@live_mode.inspect}, created_at: #{@created_at.inspect}, updated_at:"\
  " #{@updated_at.inspect}, discarded_at: #{@discarded_at.inspect}, account_number:"\
  " #{@account_number.inspect}, account_number_type: #{@account_number_type.inspect},"\
  " account_number_safe: #{@account_number_safe.inspect}>"
end

#to_custom_created_atObject



133
134
135
# File 'lib/modern_treasury/models/account_detail.rb', line 133

def to_custom_created_at
  DateTimeHelper.to_rfc3339(created_at)
end

#to_custom_discarded_atObject



141
142
143
# File 'lib/modern_treasury/models/account_detail.rb', line 141

def to_custom_discarded_at
  DateTimeHelper.to_rfc3339(discarded_at)
end

#to_custom_updated_atObject



137
138
139
# File 'lib/modern_treasury/models/account_detail.rb', line 137

def to_custom_updated_at
  DateTimeHelper.to_rfc3339(updated_at)
end

#to_sObject

Provides a human-readable string representation of the object.



192
193
194
195
196
197
198
# File 'lib/modern_treasury/models/account_detail.rb', line 192

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id}, object: #{@object}, live_mode: #{@live_mode}, created_at:"\
  " #{@created_at}, updated_at: #{@updated_at}, discarded_at: #{@discarded_at},"\
  " account_number: #{@account_number}, account_number_type: #{@account_number_type},"\
  " account_number_safe: #{@account_number_safe}>"
end