Class: ModernTreasury::AccountDetail1
- Defined in:
- lib/modern_treasury/models/account_detail1.rb
Overview
AccountDetail1 Model.
Instance Attribute Summary collapse
-
#account_number ⇒ String
TODO: Write general description for this method.
-
#account_number_type ⇒ AccountNumberType2
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account_number:, account_number_type: SKIP, additional_properties: nil) ⇒ AccountDetail1
constructor
A new instance of AccountDetail1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_number:, account_number_type: SKIP, additional_properties: nil) ⇒ AccountDetail1
Returns a new instance of AccountDetail1.
40 41 42 43 44 45 46 47 48 |
# File 'lib/modern_treasury/models/account_detail1.rb', line 40 def initialize(account_number:, account_number_type: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @account_number = account_number @account_number_type = account_number_type unless account_number_type == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#account_number ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/modern_treasury/models/account_detail1.rb', line 14 def account_number @account_number end |
#account_number_type ⇒ AccountNumberType2
TODO: Write general description for this method
18 19 20 |
# File 'lib/modern_treasury/models/account_detail1.rb', line 18 def account_number_type @account_number_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/modern_treasury/models/account_detail1.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_number = hash.key?('account_number') ? hash['account_number'] : nil account_number_type = hash.key?('account_number_type') ? hash['account_number_type'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. AccountDetail1.new(account_number: account_number, account_number_type: account_number_type, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/modern_treasury/models/account_detail1.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['account_number'] = 'account_number' @_hash['account_number_type'] = 'account_number_type' @_hash end |
.nullables ⇒ Object
An array for nullable fields
36 37 38 |
# File 'lib/modern_treasury/models/account_detail1.rb', line 36 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 |
# File 'lib/modern_treasury/models/account_detail1.rb', line 29 def self.optionals %w[ account_number_type ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
81 82 83 84 85 |
# File 'lib/modern_treasury/models/account_detail1.rb', line 81 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_number: #{@account_number.inspect}, account_number_type:"\ " #{@account_number_type.inspect}, additional_properties: #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
74 75 76 77 78 |
# File 'lib/modern_treasury/models/account_detail1.rb', line 74 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_number: #{@account_number}, account_number_type:"\ " #{@account_number_type}, additional_properties: #{@additional_properties}>" end |