Class: ModernTreasury::AddressRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/modern_treasury/models/address_request.rb

Overview

AddressRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(line1: SKIP, line2: SKIP, locality: SKIP, region: SKIP, postal_code: SKIP, country: SKIP, additional_properties: nil) ⇒ AddressRequest

Returns a new instance of AddressRequest.



72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/modern_treasury/models/address_request.rb', line 72

def initialize(line1: SKIP, line2: SKIP, locality: SKIP, region: SKIP,
               postal_code: SKIP, country: SKIP, additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @line1 = line1 unless line1 == SKIP
  @line2 = line2 unless line2 == SKIP
  @locality = locality unless locality == SKIP
  @region = region unless region == SKIP
  @postal_code = postal_code unless postal_code == SKIP
  @country = country unless country == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#countryString

Country code conforms to [ISO 3166-1 alpha-2]

Returns:

  • (String)


34
35
36
# File 'lib/modern_treasury/models/address_request.rb', line 34

def country
  @country
end

#line1String

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/modern_treasury/models/address_request.rb', line 14

def line1
  @line1
end

#line2String

TODO: Write general description for this method

Returns:

  • (String)


18
19
20
# File 'lib/modern_treasury/models/address_request.rb', line 18

def line2
  @line2
end

#localityString

Locality or City.

Returns:

  • (String)


22
23
24
# File 'lib/modern_treasury/models/address_request.rb', line 22

def locality
  @locality
end

#postal_codeString

The postal code of the address.

Returns:

  • (String)


30
31
32
# File 'lib/modern_treasury/models/address_request.rb', line 30

def postal_code
  @postal_code
end

#regionString

Region or State.

Returns:

  • (String)


26
27
28
# File 'lib/modern_treasury/models/address_request.rb', line 26

def region
  @region
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/modern_treasury/models/address_request.rb', line 87

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  line1 = hash.key?('line1') ? hash['line1'] : SKIP
  line2 = hash.key?('line2') ? hash['line2'] : SKIP
  locality = hash.key?('locality') ? hash['locality'] : SKIP
  region = hash.key?('region') ? hash['region'] : SKIP
  postal_code = hash.key?('postal_code') ? hash['postal_code'] : SKIP
  country = hash.key?('country') ? hash['country'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  AddressRequest.new(line1: line1,
                     line2: line2,
                     locality: locality,
                     region: region,
                     postal_code: postal_code,
                     country: country,
                     additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



37
38
39
40
41
42
43
44
45
46
# File 'lib/modern_treasury/models/address_request.rb', line 37

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['line1'] = 'line1'
  @_hash['line2'] = 'line2'
  @_hash['locality'] = 'locality'
  @_hash['region'] = 'region'
  @_hash['postal_code'] = 'postal_code'
  @_hash['country'] = 'country'
  @_hash
end

.nullablesObject

An array for nullable fields



61
62
63
64
65
66
67
68
69
70
# File 'lib/modern_treasury/models/address_request.rb', line 61

def self.nullables
  %w[
    line1
    line2
    locality
    region
    postal_code
    country
  ]
end

.optionalsObject

An array for optional fields



49
50
51
52
53
54
55
56
57
58
# File 'lib/modern_treasury/models/address_request.rb', line 49

def self.optionals
  %w[
    line1
    line2
    locality
    region
    postal_code
    country
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



124
125
126
127
128
129
# File 'lib/modern_treasury/models/address_request.rb', line 124

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} line1: #{@line1.inspect}, line2: #{@line2.inspect}, locality:"\
  " #{@locality.inspect}, region: #{@region.inspect}, postal_code: #{@postal_code.inspect},"\
  " country: #{@country.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



116
117
118
119
120
121
# File 'lib/modern_treasury/models/address_request.rb', line 116

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} line1: #{@line1}, line2: #{@line2}, locality: #{@locality}, region:"\
  " #{@region}, postal_code: #{@postal_code}, country: #{@country}, additional_properties:"\
  " #{@additional_properties}>"
end