Class: ModernTreasury::Balances
- Defined in:
- lib/modern_treasury/models/balances.rb
Overview
Balances Model.
Instance Attribute Summary collapse
-
#effective_at ⇒ DateTime
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(effective_at: SKIP) ⇒ Balances
constructor
A new instance of Balances.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_effective_at ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(effective_at: SKIP) ⇒ Balances
Returns a new instance of Balances.
36 37 38 |
# File 'lib/modern_treasury/models/balances.rb', line 36 def initialize(effective_at: SKIP) @effective_at = effective_at unless effective_at == SKIP end |
Instance Attribute Details
#effective_at ⇒ DateTime
TODO: Write general description for this method
15 16 17 |
# File 'lib/modern_treasury/models/balances.rb', line 15 def effective_at @effective_at end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
41 42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/modern_treasury/models/balances.rb', line 41 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. effective_at = if hash.key?('effective_at') (DateTimeHelper.from_rfc3339(hash['effective_at']) if hash['effective_at']) else SKIP end # Create object from extracted values. Balances.new(effective_at: effective_at) end |
.names ⇒ Object
A mapping from model property names to API property names.
18 19 20 21 22 |
# File 'lib/modern_treasury/models/balances.rb', line 18 def self.names @_hash = {} if @_hash.nil? @_hash['effective_at'] = 'effective_at' @_hash end |
.nullables ⇒ Object
An array for nullable fields
32 33 34 |
# File 'lib/modern_treasury/models/balances.rb', line 32 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
25 26 27 28 29 |
# File 'lib/modern_treasury/models/balances.rb', line 25 def self.optionals %w[ effective_at ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 |
# File 'lib/modern_treasury/models/balances.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} effective_at: #{@effective_at.inspect}>" end |
#to_custom_effective_at ⇒ Object
55 56 57 |
# File 'lib/modern_treasury/models/balances.rb', line 55 def to_custom_effective_at DateTimeHelper.to_rfc3339(effective_at) end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/modern_treasury/models/balances.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} effective_at: #{@effective_at}>" end |