Class: ModernTreasury::ContactDetail

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/modern_treasury/models/contact_detail.rb

Overview

ContactDetail Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id:, object:, live_mode:, created_at:, updated_at:, discarded_at:, contact_identifier:, contact_identifier_type:) ⇒ ContactDetail

Returns a new instance of ContactDetail.



77
78
79
80
81
82
83
84
85
86
87
# File 'lib/modern_treasury/models/contact_detail.rb', line 77

def initialize(id:, object:, live_mode:, created_at:, updated_at:,
               discarded_at:, contact_identifier:, contact_identifier_type:)
  @id = id
  @object = object
  @live_mode = live_mode
  @created_at = created_at
  @updated_at = updated_at
  @discarded_at = discarded_at
  @contact_identifier = contact_identifier
  @contact_identifier_type = contact_identifier_type
end

Instance Attribute Details

#contact_identifierString

This field will be true if this object exists in the live environment or false if it exists in the test environment.

Returns:

  • (String)


44
45
46
# File 'lib/modern_treasury/models/contact_detail.rb', line 44

def contact_identifier
  @contact_identifier
end

#contact_identifier_typeContactIdentifierType

This field will be true if this object exists in the live environment or false if it exists in the test environment.



49
50
51
# File 'lib/modern_treasury/models/contact_detail.rb', line 49

def contact_identifier_type
  @contact_identifier_type
end

#created_atDateTime

This field will be true if this object exists in the live environment or false if it exists in the test environment.

Returns:

  • (DateTime)


29
30
31
# File 'lib/modern_treasury/models/contact_detail.rb', line 29

def created_at
  @created_at
end

#discarded_atDateTime

This field will be true if this object exists in the live environment or false if it exists in the test environment.

Returns:

  • (DateTime)


39
40
41
# File 'lib/modern_treasury/models/contact_detail.rb', line 39

def discarded_at
  @discarded_at
end

#idUUID | String

TODO: Write general description for this method

Returns:

  • (UUID | String)


15
16
17
# File 'lib/modern_treasury/models/contact_detail.rb', line 15

def id
  @id
end

#live_modeTrueClass | FalseClass

This field will be true if this object exists in the live environment or false if it exists in the test environment.

Returns:

  • (TrueClass | FalseClass)


24
25
26
# File 'lib/modern_treasury/models/contact_detail.rb', line 24

def live_mode
  @live_mode
end

#objectString

TODO: Write general description for this method

Returns:

  • (String)


19
20
21
# File 'lib/modern_treasury/models/contact_detail.rb', line 19

def object
  @object
end

#updated_atDateTime

This field will be true if this object exists in the live environment or false if it exists in the test environment.

Returns:

  • (DateTime)


34
35
36
# File 'lib/modern_treasury/models/contact_detail.rb', line 34

def updated_at
  @updated_at
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/modern_treasury/models/contact_detail.rb', line 90

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : nil
  object = hash.key?('object') ? hash['object'] : nil
  live_mode = hash.key?('live_mode') ? hash['live_mode'] : nil
  created_at = if hash.key?('created_at')
                 (DateTimeHelper.from_rfc3339(hash['created_at']) if hash['created_at'])
               end
  updated_at = if hash.key?('updated_at')
                 (DateTimeHelper.from_rfc3339(hash['updated_at']) if hash['updated_at'])
               end
  discarded_at = if hash.key?('discarded_at')
                   (DateTimeHelper.from_rfc3339(hash['discarded_at']) if hash['discarded_at'])
                 end
  contact_identifier =
    hash.key?('contact_identifier') ? hash['contact_identifier'] : nil
  contact_identifier_type =
    hash.key?('contact_identifier_type') ? hash['contact_identifier_type'] : nil

  # Create object from extracted values.
  ContactDetail.new(id: id,
                    object: object,
                    live_mode: live_mode,
                    created_at: created_at,
                    updated_at: updated_at,
                    discarded_at: discarded_at,
                    contact_identifier: contact_identifier,
                    contact_identifier_type: contact_identifier_type)
end

.namesObject

A mapping from model property names to API property names.



52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/modern_treasury/models/contact_detail.rb', line 52

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id'] = 'id'
  @_hash['object'] = 'object'
  @_hash['live_mode'] = 'live_mode'
  @_hash['created_at'] = 'created_at'
  @_hash['updated_at'] = 'updated_at'
  @_hash['discarded_at'] = 'discarded_at'
  @_hash['contact_identifier'] = 'contact_identifier'
  @_hash['contact_identifier_type'] = 'contact_identifier_type'
  @_hash
end

.nullablesObject

An array for nullable fields



71
72
73
74
75
# File 'lib/modern_treasury/models/contact_detail.rb', line 71

def self.nullables
  %w[
    discarded_at
  ]
end

.optionalsObject

An array for optional fields



66
67
68
# File 'lib/modern_treasury/models/contact_detail.rb', line 66

def self.optionals
  []
end

.validate(value) ⇒ Object

Validates an instance of the object from a given value.

Parameters:

  • The (ContactDetail | Hash)

    value against the validation is performed.



136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/modern_treasury/models/contact_detail.rb', line 136

def self.validate(value)
  if value.instance_of? self
    return (
      APIHelper.valid_type?(value.id,
                            ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.object,
                              ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.live_mode,
                              ->(val) { val.instance_of? TrueClass or val.instance_of? FalseClass }) and
        APIHelper.valid_type?(value.created_at,
                              ->(val) { val.instance_of? DateTime }) and
        APIHelper.valid_type?(value.updated_at,
                              ->(val) { val.instance_of? DateTime }) and
        APIHelper.valid_type?(value.discarded_at,
                              ->(val) { val.instance_of? DateTime }) and
        APIHelper.valid_type?(value.contact_identifier,
                              ->(val) { val.instance_of? String }) and
        APIHelper.valid_type?(value.contact_identifier_type,
                              ->(val) { ContactIdentifierType.validate(val) })
    )
  end

  return false unless value.instance_of? Hash

  (
    APIHelper.valid_type?(value['id'],
                          ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['object'],
                            ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['live_mode'],
                            ->(val) { val.instance_of? TrueClass or val.instance_of? FalseClass }) and
      APIHelper.valid_type?(value['created_at'],
                            ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['updated_at'],
                            ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['discarded_at'],
                            ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['contact_identifier'],
                            ->(val) { val.instance_of? String }) and
      APIHelper.valid_type?(value['contact_identifier_type'],
                            ->(val) { ContactIdentifierType.validate(val) })
  )
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



190
191
192
193
194
195
196
197
# File 'lib/modern_treasury/models/contact_detail.rb', line 190

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id.inspect}, object: #{@object.inspect}, live_mode:"\
  " #{@live_mode.inspect}, created_at: #{@created_at.inspect}, updated_at:"\
  " #{@updated_at.inspect}, discarded_at: #{@discarded_at.inspect}, contact_identifier:"\
  " #{@contact_identifier.inspect}, contact_identifier_type:"\
  " #{@contact_identifier_type.inspect}>"
end

#to_custom_created_atObject



122
123
124
# File 'lib/modern_treasury/models/contact_detail.rb', line 122

def to_custom_created_at
  DateTimeHelper.to_rfc3339(created_at)
end

#to_custom_discarded_atObject



130
131
132
# File 'lib/modern_treasury/models/contact_detail.rb', line 130

def to_custom_discarded_at
  DateTimeHelper.to_rfc3339(discarded_at)
end

#to_custom_updated_atObject



126
127
128
# File 'lib/modern_treasury/models/contact_detail.rb', line 126

def to_custom_updated_at
  DateTimeHelper.to_rfc3339(updated_at)
end

#to_sObject

Provides a human-readable string representation of the object.



181
182
183
184
185
186
187
# File 'lib/modern_treasury/models/contact_detail.rb', line 181

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id}, object: #{@object}, live_mode: #{@live_mode}, created_at:"\
  " #{@created_at}, updated_at: #{@updated_at}, discarded_at: #{@discarded_at},"\
  " contact_identifier: #{@contact_identifier}, contact_identifier_type:"\
  " #{@contact_identifier_type}>"
end