Class: ModernTreasury::CounterpartyApi

Inherits:
BaseApi
  • Object
show all
Defined in:
lib/modern_treasury/apis/counterparty_api.rb

Overview

CounterpartyApi

Constant Summary

Constants inherited from BaseApi

BaseApi::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseApi

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseApi

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters

Constructor Details

This class inherits a constructor from ModernTreasury::BaseApi

Instance Method Details

#collect_account_details(id, idempotency_key: nil, body: nil) ⇒ ApiResponse

Send an email requesting account details. something unique, preferably something like an UUID. type description here

Parameters:

  • id (String)

    Required parameter: counterparty id

  • idempotency_key (String) (defaults to: nil)

    Optional parameter: This key should be

  • body (CounterpartyCollectAccountRequest) (defaults to: nil)

    Optional parameter: TODO:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
# File 'lib/modern_treasury/apis/counterparty_api.rb', line 16

def (id,
                            idempotency_key: nil,
                            body: nil)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/api/counterparties/{id}/collect_account',
                                 Server::DEFAULT)
               .template_param(new_parameter(id, key: 'id')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .header_param(new_parameter(idempotency_key, key: 'Idempotency-Key'))
               .body_param(new_parameter(body))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(Single.new('basic_auth')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(CounterpartyCollectAccountResponse.method(:from_hash))
                .is_api_response(true)
                .local_error('422',
                             'unsuccessful',
                             ErrorMessageException))
    .execute
end

#create_counterparty(idempotency_key: nil, body: nil) ⇒ ApiResponse

Create a new counterparty. something unique, preferably something like an UUID. description here

Parameters:

  • idempotency_key (String) (defaults to: nil)

    Optional parameter: This key should be

  • body (CounterpartyCreateRequest) (defaults to: nil)

    Optional parameter: TODO: type

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/modern_treasury/apis/counterparty_api.rb', line 100

def create_counterparty(idempotency_key: nil,
                        body: nil)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/api/counterparties',
                                 Server::DEFAULT)
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .header_param(new_parameter(idempotency_key, key: 'Idempotency-Key'))
               .body_param(new_parameter(body))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(Single.new('basic_auth')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(Counterparty.method(:from_hash))
                .is_api_response(true)
                .local_error('415',
                             'unsuccessful',
                             ErrorMessageException)
                .local_error('422',
                             'unsuccessful',
                             ErrorMessageException))
    .execute
end

#delete_counterparty(id) ⇒ ApiResponse

Deletes a given counterparty. counterparty.

Parameters:

  • id (String)

    Required parameter: The id of an existing

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/modern_treasury/apis/counterparty_api.rb', line 183

def delete_counterparty(id)
  @api_call
    .request(new_request_builder(HttpMethodEnum::DELETE,
                                 '/api/counterparties/{id}',
                                 Server::DEFAULT)
               .template_param(new_parameter(id, key: 'id')
                                .is_required(true)
                                .should_encode(true))
               .auth(Single.new('basic_auth')))
    .response(new_response_handler
                .is_response_void(true)
                .is_api_response(true))
    .execute
end

#get_counterparty(id) ⇒ ApiResponse

Get details on a single counterparty. counterparty.

Parameters:

  • id (String)

    Required parameter: The id of an existing

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/modern_treasury/apis/counterparty_api.rb', line 129

def get_counterparty(id)
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/api/counterparties/{id}',
                                 Server::DEFAULT)
               .template_param(new_parameter(id, key: 'id')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(Single.new('basic_auth')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(Counterparty.method(:from_hash))
                .is_api_response(true)
                .local_error('404',
                             'not found',
                             ErrorMessageException))
    .execute
end

#list_counterparties(after_cursor: nil, per_page: nil, name: nil, email: nil, metadata: nil, created_at_lower_bound: nil, created_at_upper_bound: nil) ⇒ ApiResponse

Get a paginated list of all counterparties. here here of the name field. This is also case insensitive. of the email field. This is also case insensitive. you want to query for records with metadata key ‘Type` and value `Loan`, the query would be `metadata%5BType%5D=Loan`. This encodes the query parameters. return counterparties created after some datetime. return counterparties created before some datetime.

Parameters:

  • after_cursor (String) (defaults to: nil)

    Optional parameter: TODO: type description

  • per_page (Integer) (defaults to: nil)

    Optional parameter: TODO: type description

  • name (String) (defaults to: nil)

    Optional parameter: Performs a partial string match

  • email (String) (defaults to: nil)

    Optional parameter: Performs a partial string match

  • metadata (Hash[String, String]) (defaults to: nil)

    Optional parameter: For example, if

  • created_at_lower_bound (DateTime) (defaults to: nil)

    Optional parameter: Used to

  • created_at_upper_bound (DateTime) (defaults to: nil)

    Optional parameter: Used to

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/modern_treasury/apis/counterparty_api.rb', line 60

def list_counterparties(after_cursor: nil,
                        per_page: nil,
                        name: nil,
                        email: nil,
                        metadata: nil,
                        created_at_lower_bound: nil,
                        created_at_upper_bound: nil)
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/api/counterparties',
                                 Server::DEFAULT)
               .query_param(new_parameter(after_cursor, key: 'after_cursor'))
               .query_param(new_parameter(per_page, key: 'per_page'))
               .query_param(new_parameter(name, key: 'name'))
               .query_param(new_parameter(email, key: 'email'))
               .query_param(new_parameter(, key: 'metadata'))
               .query_param(new_parameter(created_at_lower_bound, key: 'created_at_lower_bound'))
               .query_param(new_parameter(created_at_upper_bound, key: 'created_at_upper_bound'))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(Single.new('basic_auth')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(Counterparty.method(:from_hash))
                .is_api_response(true)
                .is_response_array(true)
                .local_error('400',
                             'bad_request',
                             APIException)
                .local_error('401',
                             'unsuccessful',
                             ErrorMessageException))
    .execute
end

#update_counterparty(id, body: nil) ⇒ ApiResponse

Updates a given counterparty with new information. counterparty. description here

Parameters:

  • id (String)

    Required parameter: The id of an existing

  • body (CounterpartyUpdateRequest) (defaults to: nil)

    Optional parameter: TODO: type

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/modern_treasury/apis/counterparty_api.rb', line 155

def update_counterparty(id,
                        body: nil)
  @api_call
    .request(new_request_builder(HttpMethodEnum::PATCH,
                                 '/api/counterparties/{id}',
                                 Server::DEFAULT)
               .template_param(new_parameter(id, key: 'id')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(Single.new('basic_auth')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(Counterparty.method(:from_hash))
                .is_api_response(true)
                .local_error('404',
                             'not found',
                             ErrorMessageException))
    .execute
end