Class: ModernTreasury::ExpectedPaymentApi
- Defined in:
- lib/modern_treasury/apis/expected_payment_api.rb
Overview
ExpectedPaymentApi
Constant Summary
Constants inherited from BaseApi
Instance Attribute Summary
Attributes inherited from BaseApi
Instance Method Summary collapse
-
#create_expected_payment(idempotency_key: nil, body: nil) ⇒ ApiResponse
TODO: type endpoint description here something unique, preferably something like an UUID.
-
#delete_expected_payment(id) ⇒ ApiResponse
TODO: type endpoint description here.
-
#get_expected_payment(id) ⇒ ApiResponse
TODO: type endpoint description here.
-
#list_expected_payments(after_cursor: nil, per_page: nil, status: nil, internal_account_id: nil, direction: nil, type: nil, counterparty_id: nil, metadata: nil, created_at_lower_bound: nil, created_at_upper_bound: nil) ⇒ ApiResponse
TODO: type endpoint description here here here reconciled, or archived.
-
#update_expected_payment(id, body: nil) ⇒ ApiResponse
TODO: type endpoint description here description here.
Methods inherited from BaseApi
#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters
Constructor Details
This class inherits a constructor from ModernTreasury::BaseApi
Instance Method Details
#create_expected_payment(idempotency_key: nil, body: nil) ⇒ ApiResponse
TODO: type endpoint description here something unique, preferably something like an UUID. description here
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/modern_treasury/apis/expected_payment_api.rb', line 75 def create_expected_payment(idempotency_key: nil, body: nil) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/api/expected_payments', Server::DEFAULT) .header_param(new_parameter('application/json', key: 'Content-Type')) .header_param(new_parameter(idempotency_key, key: 'Idempotency-Key')) .body_param(new_parameter(body)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(Single.new('basic_auth'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(ExpectedPayment.method(:from_hash)) .is_api_response(true) .local_error('422', 'unsuccessful', ErrorMessageException)) .execute end |
#delete_expected_payment(id) ⇒ ApiResponse
TODO: type endpoint description here
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/modern_treasury/apis/expected_payment_api.rb', line 149 def delete_expected_payment(id) @api_call .request(new_request_builder(HttpMethodEnum::DELETE, '/api/expected_payments/{id}', Server::DEFAULT) .template_param(new_parameter(id, key: 'id') .is_required(true) .should_encode(true)) .header_param(new_parameter('application/json', key: 'accept')) .auth(Single.new('basic_auth'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(ExpectedPayment.method(:from_hash)) .is_api_response(true) .local_error('422', 'parameter_invalid', ErrorMessageException)) .execute end |
#get_expected_payment(id) ⇒ ApiResponse
TODO: type endpoint description here
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/modern_treasury/apis/expected_payment_api.rb', line 100 def get_expected_payment(id) @api_call .request(new_request_builder(HttpMethodEnum::GET, '/api/expected_payments/{id}', Server::DEFAULT) .template_param(new_parameter(id, key: 'id') .is_required(true) .should_encode(true)) .header_param(new_parameter('application/json', key: 'accept')) .auth(Single.new('basic_auth'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(ExpectedPayment.method(:from_hash)) .is_api_response(true) .local_error('404', 'not found', ErrorMessageException)) .execute end |
#list_expected_payments(after_cursor: nil, per_page: nil, status: nil, internal_account_id: nil, direction: nil, type: nil, counterparty_id: nil, metadata: nil, created_at_lower_bound: nil, created_at_upper_bound: nil) ⇒ ApiResponse
TODO: type endpoint description here here here reconciled, or archived. internal_account_id to see expected_payments for a specific account. check, eft, interac, provxchange, rtp,sen, sepa, signet, wire counterparty_id to see expected_payments for a specific account. you want to query for records with metadata key ‘Type` and value `Loan`, the query would be `metadata%5BType%5D=Loan`. This encodes the query parameters. return expected payments created after some datetime return expected payments created before some datetime
32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/modern_treasury/apis/expected_payment_api.rb', line 32 def list_expected_payments(after_cursor: nil, per_page: nil, status: nil, internal_account_id: nil, direction: nil, type: nil, counterparty_id: nil, metadata: nil, created_at_lower_bound: nil, created_at_upper_bound: nil) @api_call .request(new_request_builder(HttpMethodEnum::GET, '/api/expected_payments', Server::DEFAULT) .query_param(new_parameter(after_cursor, key: 'after_cursor')) .query_param(new_parameter(per_page, key: 'per_page')) .query_param(new_parameter(status, key: 'status')) .query_param(new_parameter(internal_account_id, key: 'internal_account_id')) .query_param(new_parameter(direction, key: 'direction')) .query_param(new_parameter(type, key: 'type')) .query_param(new_parameter(counterparty_id, key: 'counterparty_id')) .query_param(new_parameter(, key: 'metadata')) .query_param(new_parameter(created_at_lower_bound, key: 'created_at_lower_bound')) .query_param(new_parameter(created_at_upper_bound, key: 'created_at_upper_bound')) .header_param(new_parameter('application/json', key: 'accept')) .auth(Single.new('basic_auth'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(ExpectedPayment.method(:from_hash)) .is_api_response(true) .is_response_array(true) .local_error('401', 'unsuccessful', ErrorMessageException)) .execute end |
#update_expected_payment(id, body: nil) ⇒ ApiResponse
TODO: type endpoint description here description here
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/modern_treasury/apis/expected_payment_api.rb', line 125 def update_expected_payment(id, body: nil) @api_call .request(new_request_builder(HttpMethodEnum::PATCH, '/api/expected_payments/{id}', Server::DEFAULT) .template_param(new_parameter(id, key: 'id') .is_required(true) .should_encode(true)) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(Single.new('basic_auth'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(ExpectedPayment.method(:from_hash)) .is_api_response(true)) .execute end |