Class: ModernTreasury::File
- Defined in:
- lib/modern_treasury/models/file.rb
Overview
File Model.
Instance Attribute Summary collapse
-
#content_type ⇒ String
The MIME content type of the document.
-
#filename ⇒ String
The original filename of the document.
-
#size ⇒ Integer
The size of the document in bytes.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(size: SKIP, filename: SKIP, content_type: SKIP) ⇒ File
constructor
A new instance of File.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(size: SKIP, filename: SKIP, content_type: SKIP) ⇒ File
Returns a new instance of File.
47 48 49 50 51 |
# File 'lib/modern_treasury/models/file.rb', line 47 def initialize(size: SKIP, filename: SKIP, content_type: SKIP) @size = size unless size == SKIP @filename = filename unless filename == SKIP @content_type = content_type unless content_type == SKIP end |
Instance Attribute Details
#content_type ⇒ String
The MIME content type of the document.
22 23 24 |
# File 'lib/modern_treasury/models/file.rb', line 22 def content_type @content_type end |
#filename ⇒ String
The original filename of the document.
18 19 20 |
# File 'lib/modern_treasury/models/file.rb', line 18 def filename @filename end |
#size ⇒ Integer
The size of the document in bytes.
14 15 16 |
# File 'lib/modern_treasury/models/file.rb', line 14 def size @size end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/modern_treasury/models/file.rb', line 54 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. size = hash.key?('size') ? hash['size'] : SKIP filename = hash.key?('filename') ? hash['filename'] : SKIP content_type = hash.key?('content_type') ? hash['content_type'] : SKIP # Create object from extracted values. File.new(size: size, filename: filename, content_type: content_type) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/modern_treasury/models/file.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['size'] = 'size' @_hash['filename'] = 'filename' @_hash['content_type'] = 'content_type' @_hash end |
.nullables ⇒ Object
An array for nullable fields
43 44 45 |
# File 'lib/modern_treasury/models/file.rb', line 43 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 39 40 |
# File 'lib/modern_treasury/models/file.rb', line 34 def self.optionals %w[ size filename content_type ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
75 76 77 78 79 |
# File 'lib/modern_treasury/models/file.rb', line 75 def inspect class_name = self.class.name.split('::').last "<#{class_name} size: #{@size.inspect}, filename: #{@filename.inspect}, content_type:"\ " #{@content_type.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
69 70 71 72 |
# File 'lib/modern_treasury/models/file.rb', line 69 def to_s class_name = self.class.name.split('::').last "<#{class_name} size: #{@size}, filename: #{@filename}, content_type: #{@content_type}>" end |