Class: ModernTreasury::IncomingPaymentDetailApi

Inherits:
BaseApi
  • Object
show all
Defined in:
lib/modern_treasury/apis/incoming_payment_detail_api.rb

Overview

IncomingPaymentDetailApi

Constant Summary

Constants inherited from BaseApi

BaseApi::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseApi

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseApi

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters

Constructor Details

This class inherits a constructor from ModernTreasury::BaseApi

Instance Method Details

#create_async_incoming_payment_detail(idempotency_key: nil, body: nil) ⇒ ApiResponse

Simulate Incoming Payment Detail something unique, preferably something like an UUID. type description here

Parameters:

  • idempotency_key (String) (defaults to: nil)

    Optional parameter: This key should be

  • body (IncomingPaymentDetailCreateRequest) (defaults to: nil)

    Optional parameter: TODO:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/modern_treasury/apis/incoming_payment_detail_api.rb', line 128

def create_async_incoming_payment_detail(idempotency_key: nil,
                                         body: nil)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/api/simulations/incoming_payment_details/create_async',
                                 Server::DEFAULT)
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .header_param(new_parameter(idempotency_key, key: 'Idempotency-Key'))
               .body_param(new_parameter(body))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(Single.new('basic_auth')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(AsyncResponse.method(:from_hash))
                .is_api_response(true)
                .local_error('404',
                             'not found',
                             ErrorMessageException)
                .local_error('405',
                             'not allowed',
                             ErrorMessageException)
                .local_error('422',
                             'unsuccessful',
                             ErrorMessageException))
    .execute
end

#get_incoming_payment_detail(id) ⇒ ApiResponse

Get an existing Incoming Payment Detail. incoming payment detail.

Parameters:

  • id (String)

    Required parameter: The unique identifier of the

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/modern_treasury/apis/incoming_payment_detail_api.rb', line 72

def get_incoming_payment_detail(id)
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/api/incoming_payment_details/{id}',
                                 Server::DEFAULT)
               .template_param(new_parameter(id, key: 'id')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(Single.new('basic_auth')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(IncomingPaymentDetail.method(:from_hash))
                .is_api_response(true)
                .local_error('404',
                             'not found',
                             ErrorMessageException))
    .execute
end

#list_incoming_payment_details(after_cursor: nil, per_page: nil, direction: nil, status: nil, type: nil, as_of_date_start: nil, as_of_date_end: nil, metadata: nil, virtual_account_id: nil) ⇒ ApiResponse

Get a list of Incoming Payment Details. here here ‘debit`. incoming payment order. One of `pending`, `completed`, or `returned`. `eft`, `interac`, `rtp`, `sepa`, `signet`, or `wire`. payment details with an as_of_date starting on or after the specified date (YYYY-MM-DD). details with an as_of_date starting on or before the specified date (YYYY-MM-DD). you want to query for records with metadata key `Type` and value `Loan`, the query would be `metadata%5BType%5D=Loan`. This encodes the query parameters. payment detail is in a virtual account, the ID of the Virtual Account.

Parameters:

  • after_cursor (String) (defaults to: nil)

    Optional parameter: TODO: type description

  • per_page (Integer) (defaults to: nil)

    Optional parameter: TODO: type description

  • direction (Direction15) (defaults to: nil)

    Optional parameter: One of ‘credit` or

  • status (Status21) (defaults to: nil)

    Optional parameter: The current status of the

  • type (Type14) (defaults to: nil)

    Optional parameter: One of: ‘ach`, `book`, `check`,

  • as_of_date_start (Date) (defaults to: nil)

    Optional parameter: Filters incoming

  • as_of_date_end (Date) (defaults to: nil)

    Optional parameter: Filters incoming payment

  • metadata (Hash[String, String]) (defaults to: nil)

    Optional parameter: For example, if

  • virtual_account_id (String) (defaults to: nil)

    Optional parameter: If the incoming

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
# File 'lib/modern_treasury/apis/incoming_payment_detail_api.rb', line 33

def list_incoming_payment_details(after_cursor: nil,
                                  per_page: nil,
                                  direction: nil,
                                  status: nil,
                                  type: nil,
                                  as_of_date_start: nil,
                                  as_of_date_end: nil,
                                  metadata: nil,
                                  virtual_account_id: nil)
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/api/incoming_payment_details',
                                 Server::DEFAULT)
               .query_param(new_parameter(after_cursor, key: 'after_cursor'))
               .query_param(new_parameter(per_page, key: 'per_page'))
               .query_param(new_parameter(direction, key: 'direction'))
               .query_param(new_parameter(status, key: 'status'))
               .query_param(new_parameter(type, key: 'type'))
               .query_param(new_parameter(as_of_date_start, key: 'as_of_date_start'))
               .query_param(new_parameter(as_of_date_end, key: 'as_of_date_end'))
               .query_param(new_parameter(, key: 'metadata'))
               .query_param(new_parameter(, key: 'virtual_account_id'))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(Single.new('basic_auth')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(IncomingPaymentDetail.method(:from_hash))
                .is_api_response(true)
                .is_response_array(true)
                .local_error('401',
                             'unsuccessful',
                             ErrorMessageException))
    .execute
end

#update_incoming_payment_detail(id, body: nil) ⇒ ApiResponse

Update an existing Incoming Payment Detail. incoming payment detail. type description here

Parameters:

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/modern_treasury/apis/incoming_payment_detail_api.rb', line 98

def update_incoming_payment_detail(id,
                                   body: nil)
  @api_call
    .request(new_request_builder(HttpMethodEnum::PATCH,
                                 '/api/incoming_payment_details/{id}',
                                 Server::DEFAULT)
               .template_param(new_parameter(id, key: 'id')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(Single.new('basic_auth')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(IncomingPaymentDetail.method(:from_hash))
                .is_api_response(true)
                .local_error('404',
                             'not found',
                             ErrorMessageException))
    .execute
end