Class: ModernTreasury::InternalAccountController

Inherits:
BaseController show all
Defined in:
lib/modern_treasury/controllers/internal_account_controller.rb

Overview

InternalAccountController

Constant Summary

Constants inherited from BaseController

BaseController::GLOBAL_ERRORS

Instance Attribute Summary

Attributes inherited from BaseController

#config, #http_call_back

Instance Method Summary collapse

Methods inherited from BaseController

#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent, user_agent_parameters

Constructor Details

This class inherits a constructor from ModernTreasury::BaseController

Instance Method Details

#create_internal_account(idempotency_key: nil, body: nil) ⇒ ApiResponse

TODO: type endpoint description here something unique, preferably something like an UUID. description here

Parameters:

  • idempotency_key (String) (defaults to: nil)

    Optional parameter: This key should be

  • body (InternalAccountCreateRequest) (defaults to: nil)

    Optional parameter: TODO: type

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
# File 'lib/modern_treasury/controllers/internal_account_controller.rb', line 61

def (idempotency_key: nil,
                            body: nil)
  @api_call
    .request(new_request_builder(HttpMethodEnum::POST,
                                 '/api/internal_accounts',
                                 Server::DEFAULT)
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .header_param(new_parameter(idempotency_key, key: 'Idempotency-Key'))
               .body_param(new_parameter(body))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(Single.new('basic_auth')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(InternalAccount.method(:from_hash))
                .is_api_response(true)
                .local_error('404',
                             'not found',
                             ErrorMessageException)
                .local_error('422',
                             'unsuccessful',
                             ErrorMessageException))
    .execute
end

#get_internal_account(id) ⇒ ApiResponse

TODO: type endpoint description here account.

Parameters:

  • id (String)

    Required parameter: Unique identifier for the

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/modern_treasury/controllers/internal_account_controller.rb', line 90

def (id)
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/api/internal_accounts/{id}',
                                 Server::DEFAULT)
               .template_param(new_parameter(id, key: 'id')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(Single.new('basic_auth')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(InternalAccount.method(:from_hash))
                .is_api_response(true)
                .local_error('404',
                             'not found',
                             ErrorMessageException))
    .execute
end

#list_internal_accounts(after_cursor: nil, per_page: nil, currency: nil, counterparty_id: nil, payment_type: nil, payment_direction: nil, metadata: nil) ⇒ ApiResponse

TODO: type endpoint description here here here with the internal account. associated with the internal account. payment that can be made by the internal account. direction of payments that can be made by internal account. you want to query for records with metadata key ‘Type` and value `Loan`, the query would be `metadata%5BType%5D=Loan`. This encodes the query parameters.

Parameters:

  • after_cursor (String) (defaults to: nil)

    Optional parameter: TODO: type description

  • per_page (Integer) (defaults to: nil)

    Optional parameter: TODO: type description

  • currency (Currency) (defaults to: nil)

    Optional parameter: The currency associated

  • counterparty_id (String) (defaults to: nil)

    Optional parameter: The counterparty

  • payment_type (PaymentType13) (defaults to: nil)

    Optional parameter: The type of

  • payment_direction (PaymentDirection) (defaults to: nil)

    Optional parameter: The

  • metadata (Hash[String, String]) (defaults to: nil)

    Optional parameter: For example, if

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
# File 'lib/modern_treasury/controllers/internal_account_controller.rb', line 27

def list_internal_accounts(after_cursor: nil,
                           per_page: nil,
                           currency: nil,
                           counterparty_id: nil,
                           payment_type: nil,
                           payment_direction: nil,
                           metadata: nil)
  @api_call
    .request(new_request_builder(HttpMethodEnum::GET,
                                 '/api/internal_accounts',
                                 Server::DEFAULT)
               .query_param(new_parameter(after_cursor, key: 'after_cursor'))
               .query_param(new_parameter(per_page, key: 'per_page'))
               .query_param(new_parameter(currency, key: 'currency'))
               .query_param(new_parameter(counterparty_id, key: 'counterparty_id'))
               .query_param(new_parameter(payment_type, key: 'payment_type'))
               .query_param(new_parameter(payment_direction, key: 'payment_direction'))
               .query_param(new_parameter(, key: 'metadata'))
               .header_param(new_parameter('application/json', key: 'accept'))
               .auth(Single.new('basic_auth')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(InternalAccount.method(:from_hash))
                .is_api_response(true)
                .is_response_array(true))
    .execute
end

#update_internal_account(id, body: nil) ⇒ ApiResponse

TODO: type endpoint description here account. description here

Parameters:

  • id (String)

    Required parameter: Unique identifier for the

  • body (InternalAccountUpdateRequest) (defaults to: nil)

    Optional parameter: TODO: type

Returns:

  • (ApiResponse)

    Complete http response with raw body and status code.



116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/modern_treasury/controllers/internal_account_controller.rb', line 116

def (id,
                            body: nil)
  @api_call
    .request(new_request_builder(HttpMethodEnum::PATCH,
                                 '/api/internal_accounts/{id}',
                                 Server::DEFAULT)
               .template_param(new_parameter(id, key: 'id')
                                .is_required(true)
                                .should_encode(true))
               .header_param(new_parameter('application/json', key: 'Content-Type'))
               .body_param(new_parameter(body))
               .header_param(new_parameter('application/json', key: 'accept'))
               .body_serializer(proc do |param| param.to_json unless param.nil? end)
               .auth(Single.new('basic_auth')))
    .response(new_response_handler
                .deserializer(APIHelper.method(:custom_type_deserializer))
                .deserialize_into(InternalAccount.method(:from_hash))
                .is_api_response(true)
                .local_error('404',
                             'unsuccessful',
                             ErrorMessageException))
    .execute
end