Class: ModernTreasury::LedgerCreateRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/modern_treasury/models/ledger_create_request.rb

Overview

LedgerCreateRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(name:, description: SKIP, metadata: SKIP, additional_properties: nil) ⇒ LedgerCreateRequest

Returns a new instance of LedgerCreateRequest.



49
50
51
52
53
54
55
56
57
58
# File 'lib/modern_treasury/models/ledger_create_request.rb', line 49

def initialize(name:, description: SKIP, metadata: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @name = name
  @description = description unless description == SKIP
  @metadata =  unless  == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#descriptionString

An optional free-form description for internal use.

Returns:

  • (String)


18
19
20
# File 'lib/modern_treasury/models/ledger_create_request.rb', line 18

def description
  @description
end

#metadataHash[String, String]

Additional data represented as key-value pairs. Both the key and value must be strings.

Returns:

  • (Hash[String, String])


23
24
25
# File 'lib/modern_treasury/models/ledger_create_request.rb', line 23

def 
  @metadata
end

#nameString

The name of the ledger.

Returns:

  • (String)


14
15
16
# File 'lib/modern_treasury/models/ledger_create_request.rb', line 14

def name
  @name
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
# File 'lib/modern_treasury/models/ledger_create_request.rb', line 61

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  name = hash.key?('name') ? hash['name'] : nil
  description = hash.key?('description') ? hash['description'] : SKIP
   = hash.key?('metadata') ? hash['metadata'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  LedgerCreateRequest.new(name: name,
                          description: description,
                          metadata: ,
                          additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



26
27
28
29
30
31
32
# File 'lib/modern_treasury/models/ledger_create_request.rb', line 26

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['name'] = 'name'
  @_hash['description'] = 'description'
  @_hash['metadata'] = 'metadata'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
46
47
# File 'lib/modern_treasury/models/ledger_create_request.rb', line 43

def self.nullables
  %w[
    description
  ]
end

.optionalsObject

An array for optional fields



35
36
37
38
39
40
# File 'lib/modern_treasury/models/ledger_create_request.rb', line 35

def self.optionals
  %w[
    description
    metadata
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



91
92
93
94
95
# File 'lib/modern_treasury/models/ledger_create_request.rb', line 91

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name.inspect}, description: #{@description.inspect}, metadata:"\
  " #{@metadata.inspect}, additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



84
85
86
87
88
# File 'lib/modern_treasury/models/ledger_create_request.rb', line 84

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} name: #{@name}, description: #{@description}, metadata: #{@metadata},"\
  " additional_properties: #{@additional_properties}>"
end