Class: ModernTreasury::LedgerEventHandlerLedgerEntries
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ModernTreasury::LedgerEventHandlerLedgerEntries
- Defined in:
- lib/modern_treasury/models/ledger_event_handler_ledger_entries.rb
Overview
LedgerEventHandlerLedgerEntries Model.
Instance Attribute Summary collapse
-
#amount ⇒ String
The field you’re fetching from the ‘ledgerable_event`.
-
#direction ⇒ String
What the operator between the ‘field` and `value` is.
-
#ledger_account_id ⇒ String
What raw string you are comparing the ‘field` against.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(amount:, direction:, ledger_account_id:) ⇒ LedgerEventHandlerLedgerEntries
constructor
A new instance of LedgerEventHandlerLedgerEntries.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(amount:, direction:, ledger_account_id:) ⇒ LedgerEventHandlerLedgerEntries
Returns a new instance of LedgerEventHandlerLedgerEntries.
44 45 46 47 48 |
# File 'lib/modern_treasury/models/ledger_event_handler_ledger_entries.rb', line 44 def initialize(amount:, direction:, ledger_account_id:) @amount = amount @direction = direction @ledger_account_id = ledger_account_id end |
Instance Attribute Details
#amount ⇒ String
The field you’re fetching from the ‘ledgerable_event`.
14 15 16 |
# File 'lib/modern_treasury/models/ledger_event_handler_ledger_entries.rb', line 14 def amount @amount end |
#direction ⇒ String
What the operator between the ‘field` and `value` is. Currently only supports `equals`.
19 20 21 |
# File 'lib/modern_treasury/models/ledger_event_handler_ledger_entries.rb', line 19 def direction @direction end |
#ledger_account_id ⇒ String
What raw string you are comparing the ‘field` against.
23 24 25 |
# File 'lib/modern_treasury/models/ledger_event_handler_ledger_entries.rb', line 23 def ledger_account_id @ledger_account_id end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 |
# File 'lib/modern_treasury/models/ledger_event_handler_ledger_entries.rb', line 51 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. amount = hash.key?('amount') ? hash['amount'] : nil direction = hash.key?('direction') ? hash['direction'] : nil ledger_account_id = hash.key?('ledger_account_id') ? hash['ledger_account_id'] : nil # Create object from extracted values. LedgerEventHandlerLedgerEntries.new(amount: amount, direction: direction, ledger_account_id: ledger_account_id) end |
.names ⇒ Object
A mapping from model property names to API property names.
26 27 28 29 30 31 32 |
# File 'lib/modern_treasury/models/ledger_event_handler_ledger_entries.rb', line 26 def self.names @_hash = {} if @_hash.nil? @_hash['amount'] = 'amount' @_hash['direction'] = 'direction' @_hash['ledger_account_id'] = 'ledger_account_id' @_hash end |
.nullables ⇒ Object
An array for nullable fields
40 41 42 |
# File 'lib/modern_treasury/models/ledger_event_handler_ledger_entries.rb', line 40 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
35 36 37 |
# File 'lib/modern_treasury/models/ledger_event_handler_ledger_entries.rb', line 35 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
74 75 76 77 78 |
# File 'lib/modern_treasury/models/ledger_event_handler_ledger_entries.rb', line 74 def inspect class_name = self.class.name.split('::').last "<#{class_name} amount: #{@amount.inspect}, direction: #{@direction.inspect},"\ " ledger_account_id: #{@ledger_account_id.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
67 68 69 70 71 |
# File 'lib/modern_treasury/models/ledger_event_handler_ledger_entries.rb', line 67 def to_s class_name = self.class.name.split('::').last "<#{class_name} amount: #{@amount}, direction: #{@direction}, ledger_account_id:"\ " #{@ledger_account_id}>" end |