Class: ModernTreasury::LegacyDocumentCreateRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ModernTreasury::LegacyDocumentCreateRequest
- Defined in:
- lib/modern_treasury/models/legacy_document_create_request.rb
Overview
LegacyDocumentCreateRequest Model.
Instance Attribute Summary collapse
-
#document_type ⇒ String
A category given to the document, can be ‘null`.
-
#file ⇒ Binary
A category given to the document, can be ‘null`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(file = nil, document_type = SKIP) ⇒ LegacyDocumentCreateRequest
constructor
A new instance of LegacyDocumentCreateRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(file = nil, document_type = SKIP) ⇒ LegacyDocumentCreateRequest
Returns a new instance of LegacyDocumentCreateRequest.
40 41 42 43 |
# File 'lib/modern_treasury/models/legacy_document_create_request.rb', line 40 def initialize(file = nil, document_type = SKIP) @document_type = document_type unless document_type == SKIP @file = file end |
Instance Attribute Details
#document_type ⇒ String
A category given to the document, can be ‘null`.
14 15 16 |
# File 'lib/modern_treasury/models/legacy_document_create_request.rb', line 14 def document_type @document_type end |
#file ⇒ Binary
A category given to the document, can be ‘null`.
18 19 20 |
# File 'lib/modern_treasury/models/legacy_document_create_request.rb', line 18 def file @file end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
46 47 48 49 50 51 52 53 54 55 56 |
# File 'lib/modern_treasury/models/legacy_document_create_request.rb', line 46 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. file = hash.key?('file') ? hash['file'] : nil document_type = hash.key?('document_type') ? hash['document_type'] : SKIP # Create object from extracted values. LegacyDocumentCreateRequest.new(file, document_type) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/modern_treasury/models/legacy_document_create_request.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['document_type'] = 'document_type' @_hash['file'] = 'file' @_hash end |
.nullables ⇒ Object
An array for nullable fields
36 37 38 |
# File 'lib/modern_treasury/models/legacy_document_create_request.rb', line 36 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 |
# File 'lib/modern_treasury/models/legacy_document_create_request.rb', line 29 def self.optionals %w[ document_type ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
65 66 67 68 |
# File 'lib/modern_treasury/models/legacy_document_create_request.rb', line 65 def inspect class_name = self.class.name.split('::').last "<#{class_name} document_type: #{@document_type.inspect}, file: #{@file.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
59 60 61 62 |
# File 'lib/modern_treasury/models/legacy_document_create_request.rb', line 59 def to_s class_name = self.class.name.split('::').last "<#{class_name} document_type: #{@document_type}, file: #{@file}>" end |