Class: ModernTreasury::OrderBy
- Defined in:
- lib/modern_treasury/models/order_by.rb
Overview
OrderBy Model.
Instance Attribute Summary collapse
-
#created_at ⇒ CreatedAt
TODO: Write general description for this method.
-
#effective_at ⇒ EffectiveAt
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(created_at: SKIP, effective_at: SKIP) ⇒ OrderBy
constructor
A new instance of OrderBy.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(created_at: SKIP, effective_at: SKIP) ⇒ OrderBy
Returns a new instance of OrderBy.
41 42 43 44 |
# File 'lib/modern_treasury/models/order_by.rb', line 41 def initialize(created_at: SKIP, effective_at: SKIP) @created_at = created_at unless created_at == SKIP @effective_at = effective_at unless effective_at == SKIP end |
Instance Attribute Details
#created_at ⇒ CreatedAt
TODO: Write general description for this method
14 15 16 |
# File 'lib/modern_treasury/models/order_by.rb', line 14 def created_at @created_at end |
#effective_at ⇒ EffectiveAt
TODO: Write general description for this method
18 19 20 |
# File 'lib/modern_treasury/models/order_by.rb', line 18 def effective_at @effective_at end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/modern_treasury/models/order_by.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. created_at = hash.key?('created_at') ? hash['created_at'] : SKIP effective_at = hash.key?('effective_at') ? hash['effective_at'] : SKIP # Create object from extracted values. OrderBy.new(created_at: created_at, effective_at: effective_at) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/modern_treasury/models/order_by.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['created_at'] = 'created_at' @_hash['effective_at'] = 'effective_at' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/modern_treasury/models/order_by.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/modern_treasury/models/order_by.rb', line 29 def self.optionals %w[ created_at effective_at ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
66 67 68 69 70 |
# File 'lib/modern_treasury/models/order_by.rb', line 66 def inspect class_name = self.class.name.split('::').last "<#{class_name} created_at: #{@created_at.inspect}, effective_at:"\ " #{@effective_at.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
60 61 62 63 |
# File 'lib/modern_treasury/models/order_by.rb', line 60 def to_s class_name = self.class.name.split('::').last "<#{class_name} created_at: #{@created_at}, effective_at: #{@effective_at}>" end |