Class: ModernTreasury::Reversal
- Defined in:
- lib/modern_treasury/models/reversal.rb
Overview
Reversal Model.
Instance Attribute Summary collapse
-
#created_at ⇒ DateTime
This field will be true if this object exists in the live environment or false if it exists in the test environment.
-
#id ⇒ UUID | String
TODO: Write general description for this method.
-
#live_mode ⇒ TrueClass | FalseClass
This field will be true if this object exists in the live environment or false if it exists in the test environment.
-
#metadata ⇒ Hash[String, String]
Additional data represented as key-value pairs.
-
#object ⇒ String
TODO: Write general description for this method.
-
#payment_order_id ⇒ UUID | String
The ID of the relevant Payment Order.
-
#reason ⇒ Reason
The reason for the reversal.
-
#status ⇒ Status19
The current status of the reversal.
-
#updated_at ⇒ DateTime
This field will be true if this object exists in the live environment or false if it exists in the test environment.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(id:, object:, live_mode:, created_at:, updated_at:, status:, payment_order_id:, metadata:, reason:) ⇒ Reversal
constructor
A new instance of Reversal.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_created_at ⇒ Object
- #to_custom_updated_at ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id:, object:, live_mode:, created_at:, updated_at:, status:, payment_order_id:, metadata:, reason:) ⇒ Reversal
Returns a new instance of Reversal.
80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/modern_treasury/models/reversal.rb', line 80 def initialize(id:, object:, live_mode:, created_at:, updated_at:, status:, payment_order_id:, metadata:, reason:) @id = id @object = object @live_mode = live_mode @created_at = created_at @updated_at = updated_at @status = status @payment_order_id = payment_order_id @metadata = @reason = reason end |
Instance Attribute Details
#created_at ⇒ DateTime
This field will be true if this object exists in the live environment or false if it exists in the test environment.
29 30 31 |
# File 'lib/modern_treasury/models/reversal.rb', line 29 def created_at @created_at end |
#id ⇒ UUID | String
TODO: Write general description for this method
15 16 17 |
# File 'lib/modern_treasury/models/reversal.rb', line 15 def id @id end |
#live_mode ⇒ TrueClass | FalseClass
This field will be true if this object exists in the live environment or false if it exists in the test environment.
24 25 26 |
# File 'lib/modern_treasury/models/reversal.rb', line 24 def live_mode @live_mode end |
#metadata ⇒ Hash[String, String]
Additional data represented as key-value pairs. Both the key and value must be strings.
47 48 49 |
# File 'lib/modern_treasury/models/reversal.rb', line 47 def @metadata end |
#object ⇒ String
TODO: Write general description for this method
19 20 21 |
# File 'lib/modern_treasury/models/reversal.rb', line 19 def object @object end |
#payment_order_id ⇒ UUID | String
The ID of the relevant Payment Order.
42 43 44 |
# File 'lib/modern_treasury/models/reversal.rb', line 42 def payment_order_id @payment_order_id end |
#reason ⇒ Reason
The reason for the reversal.
51 52 53 |
# File 'lib/modern_treasury/models/reversal.rb', line 51 def reason @reason end |
#status ⇒ Status19
The current status of the reversal.
38 39 40 |
# File 'lib/modern_treasury/models/reversal.rb', line 38 def status @status end |
#updated_at ⇒ DateTime
This field will be true if this object exists in the live environment or false if it exists in the test environment.
34 35 36 |
# File 'lib/modern_treasury/models/reversal.rb', line 34 def updated_at @updated_at end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/modern_treasury/models/reversal.rb', line 94 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : nil object = hash.key?('object') ? hash['object'] : nil live_mode = hash.key?('live_mode') ? hash['live_mode'] : nil created_at = if hash.key?('created_at') (DateTimeHelper.from_rfc3339(hash['created_at']) if hash['created_at']) end updated_at = if hash.key?('updated_at') (DateTimeHelper.from_rfc3339(hash['updated_at']) if hash['updated_at']) end status = hash.key?('status') ? hash['status'] : nil payment_order_id = hash.key?('payment_order_id') ? hash['payment_order_id'] : nil = hash.key?('metadata') ? hash['metadata'] : nil reason = hash.key?('reason') ? hash['reason'] : nil # Create object from extracted values. Reversal.new(id: id, object: object, live_mode: live_mode, created_at: created_at, updated_at: updated_at, status: status, payment_order_id: payment_order_id, metadata: , reason: reason) end |
.names ⇒ Object
A mapping from model property names to API property names.
54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/modern_treasury/models/reversal.rb', line 54 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['object'] = 'object' @_hash['live_mode'] = 'live_mode' @_hash['created_at'] = 'created_at' @_hash['updated_at'] = 'updated_at' @_hash['status'] = 'status' @_hash['payment_order_id'] = 'payment_order_id' @_hash['metadata'] = 'metadata' @_hash['reason'] = 'reason' @_hash end |
.nullables ⇒ Object
An array for nullable fields
74 75 76 77 78 |
# File 'lib/modern_treasury/models/reversal.rb', line 74 def self.nullables %w[ payment_order_id ] end |
.optionals ⇒ Object
An array for optional fields
69 70 71 |
# File 'lib/modern_treasury/models/reversal.rb', line 69 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
142 143 144 145 146 147 148 |
# File 'lib/modern_treasury/models/reversal.rb', line 142 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, object: #{@object.inspect}, live_mode:"\ " #{@live_mode.inspect}, created_at: #{@created_at.inspect}, updated_at:"\ " #{@updated_at.inspect}, status: #{@status.inspect}, payment_order_id:"\ " #{@payment_order_id.inspect}, metadata: #{@metadata.inspect}, reason: #{@reason.inspect}>" end |
#to_custom_created_at ⇒ Object
125 126 127 |
# File 'lib/modern_treasury/models/reversal.rb', line 125 def to_custom_created_at DateTimeHelper.to_rfc3339(created_at) end |
#to_custom_updated_at ⇒ Object
129 130 131 |
# File 'lib/modern_treasury/models/reversal.rb', line 129 def to_custom_updated_at DateTimeHelper.to_rfc3339(updated_at) end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
134 135 136 137 138 139 |
# File 'lib/modern_treasury/models/reversal.rb', line 134 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, object: #{@object}, live_mode: #{@live_mode}, created_at:"\ " #{@created_at}, updated_at: #{@updated_at}, status: #{@status}, payment_order_id:"\ " #{@payment_order_id}, metadata: #{@metadata}, reason: #{@reason}>" end |