Class: ModernTreasury::AccountCollectionFlowCreateRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ModernTreasury::AccountCollectionFlowCreateRequest
- Defined in:
- lib/modern_treasury/models/account_collection_flow_create_request.rb
Overview
AccountCollectionFlowCreateRequest Model.
Instance Attribute Summary collapse
-
#counterparty_id ⇒ UUID | String
Required.
-
#payment_types ⇒ Array[String]
Required.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(counterparty_id = nil, payment_types = nil) ⇒ AccountCollectionFlowCreateRequest
constructor
A new instance of AccountCollectionFlowCreateRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(counterparty_id = nil, payment_types = nil) ⇒ AccountCollectionFlowCreateRequest
Returns a new instance of AccountCollectionFlowCreateRequest.
38 39 40 41 |
# File 'lib/modern_treasury/models/account_collection_flow_create_request.rb', line 38 def initialize(counterparty_id = nil, payment_types = nil) @counterparty_id = counterparty_id @payment_types = payment_types end |
Instance Attribute Details
#counterparty_id ⇒ UUID | String
Required.
14 15 16 |
# File 'lib/modern_treasury/models/account_collection_flow_create_request.rb', line 14 def counterparty_id @counterparty_id end |
#payment_types ⇒ Array[String]
Required.
18 19 20 |
# File 'lib/modern_treasury/models/account_collection_flow_create_request.rb', line 18 def payment_types @payment_types end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/modern_treasury/models/account_collection_flow_create_request.rb', line 44 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. counterparty_id = hash.key?('counterparty_id') ? hash['counterparty_id'] : nil payment_types = hash.key?('payment_types') ? hash['payment_types'] : nil # Create object from extracted values. AccountCollectionFlowCreateRequest.new(counterparty_id, payment_types) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/modern_treasury/models/account_collection_flow_create_request.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['counterparty_id'] = 'counterparty_id' @_hash['payment_types'] = 'payment_types' @_hash end |
.nullables ⇒ Object
An array for nullable fields
34 35 36 |
# File 'lib/modern_treasury/models/account_collection_flow_create_request.rb', line 34 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 |
# File 'lib/modern_treasury/models/account_collection_flow_create_request.rb', line 29 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
64 65 66 67 68 |
# File 'lib/modern_treasury/models/account_collection_flow_create_request.rb', line 64 def inspect class_name = self.class.name.split('::').last "<#{class_name} counterparty_id: #{@counterparty_id.inspect}, payment_types:"\ " #{@payment_types.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
58 59 60 61 |
# File 'lib/modern_treasury/models/account_collection_flow_create_request.rb', line 58 def to_s class_name = self.class.name.split('::').last "<#{class_name} counterparty_id: #{@counterparty_id}, payment_types: #{@payment_types}>" end |