Class: ModernTreasury::AccountDetailCreateRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/modern_treasury/models/account_detail_create_request.rb

Overview

AccountDetailCreateRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(account_number = nil, account_number_type = SKIP) ⇒ AccountDetailCreateRequest

Returns a new instance of AccountDetailCreateRequest.



41
42
43
44
# File 'lib/modern_treasury/models/account_detail_create_request.rb', line 41

def initialize( = nil,  = SKIP)
  @account_number = 
  @account_number_type =  unless  == SKIP
end

Instance Attribute Details

#account_numberString

The account number for the bank account.

Returns:

  • (String)


14
15
16
# File 'lib/modern_treasury/models/account_detail_create_request.rb', line 14

def 
  @account_number
end

#account_number_typeAccountNumberTypeEnum

One of ‘iban`, `clabe`, `wallet_address`, or `other`. Use `other` if the bank account number is in a generic format.



19
20
21
# File 'lib/modern_treasury/models/account_detail_create_request.rb', line 19

def 
  @account_number_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



47
48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/modern_treasury/models/account_detail_create_request.rb', line 47

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
   =
    hash.key?('account_number') ? hash['account_number'] : nil
   =
    hash.key?('account_number_type') ? hash['account_number_type'] : SKIP

  # Create object from extracted values.
  AccountDetailCreateRequest.new(,
                                 )
end

.namesObject

A mapping from model property names to API property names.



22
23
24
25
26
27
# File 'lib/modern_treasury/models/account_detail_create_request.rb', line 22

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['account_number'] = 'account_number'
  @_hash['account_number_type'] = 'account_number_type'
  @_hash
end

.nullablesObject

An array for nullable fields



37
38
39
# File 'lib/modern_treasury/models/account_detail_create_request.rb', line 37

def self.nullables
  []
end

.optionalsObject

An array for optional fields



30
31
32
33
34
# File 'lib/modern_treasury/models/account_detail_create_request.rb', line 30

def self.optionals
  %w[
    account_number_type
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



69
70
71
72
73
# File 'lib/modern_treasury/models/account_detail_create_request.rb', line 69

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} account_number: #{@account_number.inspect}, account_number_type:"\
  " #{@account_number_type.inspect}>"
end

#to_sObject

Provides a human-readable string representation of the object.



62
63
64
65
66
# File 'lib/modern_treasury/models/account_detail_create_request.rb', line 62

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} account_number: #{@account_number}, account_number_type:"\
  " #{@account_number_type}>"
end