Class: ModernTreasury::AccountDetailCreateRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ModernTreasury::AccountDetailCreateRequest
- Defined in:
- lib/modern_treasury/models/account_detail_create_request.rb
Overview
AccountDetailCreateRequest Model.
Instance Attribute Summary collapse
-
#account_number ⇒ String
The account number for the bank account.
-
#account_number_type ⇒ AccountNumberTypeEnum
One of ‘iban`, `clabe`, `wallet_address`, or `other`.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(account_number = nil, account_number_type = SKIP) ⇒ AccountDetailCreateRequest
constructor
A new instance of AccountDetailCreateRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(account_number = nil, account_number_type = SKIP) ⇒ AccountDetailCreateRequest
Returns a new instance of AccountDetailCreateRequest.
41 42 43 44 |
# File 'lib/modern_treasury/models/account_detail_create_request.rb', line 41 def initialize(account_number = nil, account_number_type = SKIP) @account_number = account_number @account_number_type = account_number_type unless account_number_type == SKIP end |
Instance Attribute Details
#account_number ⇒ String
The account number for the bank account.
14 15 16 |
# File 'lib/modern_treasury/models/account_detail_create_request.rb', line 14 def account_number @account_number end |
#account_number_type ⇒ AccountNumberTypeEnum
One of ‘iban`, `clabe`, `wallet_address`, or `other`. Use `other` if the bank account number is in a generic format.
19 20 21 |
# File 'lib/modern_treasury/models/account_detail_create_request.rb', line 19 def account_number_type @account_number_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/modern_treasury/models/account_detail_create_request.rb', line 47 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. account_number = hash.key?('account_number') ? hash['account_number'] : nil account_number_type = hash.key?('account_number_type') ? hash['account_number_type'] : SKIP # Create object from extracted values. AccountDetailCreateRequest.new(account_number, account_number_type) end |
.names ⇒ Object
A mapping from model property names to API property names.
22 23 24 25 26 27 |
# File 'lib/modern_treasury/models/account_detail_create_request.rb', line 22 def self.names @_hash = {} if @_hash.nil? @_hash['account_number'] = 'account_number' @_hash['account_number_type'] = 'account_number_type' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/modern_treasury/models/account_detail_create_request.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
30 31 32 33 34 |
# File 'lib/modern_treasury/models/account_detail_create_request.rb', line 30 def self.optionals %w[ account_number_type ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
69 70 71 72 73 |
# File 'lib/modern_treasury/models/account_detail_create_request.rb', line 69 def inspect class_name = self.class.name.split('::').last "<#{class_name} account_number: #{@account_number.inspect}, account_number_type:"\ " #{@account_number_type.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
62 63 64 65 66 |
# File 'lib/modern_treasury/models/account_detail_create_request.rb', line 62 def to_s class_name = self.class.name.split('::').last "<#{class_name} account_number: #{@account_number}, account_number_type:"\ " #{@account_number_type}>" end |