Class: ModernTreasury::ContactDetailCreateRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ModernTreasury::ContactDetailCreateRequest
- Defined in:
- lib/modern_treasury/models/contact_detail_create_request.rb
Overview
ContactDetailCreateRequest Model.
Instance Attribute Summary collapse
-
#contact_identifier ⇒ String
TODO: Write general description for this method.
-
#contact_identifier_type ⇒ ContactIdentifierType
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(contact_identifier: SKIP, contact_identifier_type: SKIP, additional_properties: nil) ⇒ ContactDetailCreateRequest
constructor
A new instance of ContactDetailCreateRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(contact_identifier: SKIP, contact_identifier_type: SKIP, additional_properties: nil) ⇒ ContactDetailCreateRequest
Returns a new instance of ContactDetailCreateRequest.
41 42 43 44 45 46 47 48 49 |
# File 'lib/modern_treasury/models/contact_detail_create_request.rb', line 41 def initialize(contact_identifier: SKIP, contact_identifier_type: SKIP, additional_properties: nil) # Add additional model properties to the instance additional_properties = {} if additional_properties.nil? @contact_identifier = contact_identifier unless contact_identifier == SKIP @contact_identifier_type = contact_identifier_type unless contact_identifier_type == SKIP @additional_properties = additional_properties end |
Instance Attribute Details
#contact_identifier ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/modern_treasury/models/contact_detail_create_request.rb', line 14 def contact_identifier @contact_identifier end |
#contact_identifier_type ⇒ ContactIdentifierType
TODO: Write general description for this method
18 19 20 |
# File 'lib/modern_treasury/models/contact_detail_create_request.rb', line 18 def contact_identifier_type @contact_identifier_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/modern_treasury/models/contact_detail_create_request.rb', line 52 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. contact_identifier = hash.key?('contact_identifier') ? hash['contact_identifier'] : SKIP contact_identifier_type = hash.key?('contact_identifier_type') ? hash['contact_identifier_type'] : SKIP # Create a new hash for additional properties, removing known properties. new_hash = hash.reject { |k, _| names.value?(k) } additional_properties = APIHelper.get_additional_properties( new_hash, proc { |value| value } ) # Create object from extracted values. ContactDetailCreateRequest.new(contact_identifier: contact_identifier, contact_identifier_type: contact_identifier_type, additional_properties: additional_properties) end |
.names ⇒ Object
A mapping from model property names to API property names.
21 22 23 24 25 26 |
# File 'lib/modern_treasury/models/contact_detail_create_request.rb', line 21 def self.names @_hash = {} if @_hash.nil? @_hash['contact_identifier'] = 'contact_identifier' @_hash['contact_identifier_type'] = 'contact_identifier_type' @_hash end |
.nullables ⇒ Object
An array for nullable fields
37 38 39 |
# File 'lib/modern_treasury/models/contact_detail_create_request.rb', line 37 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
29 30 31 32 33 34 |
# File 'lib/modern_treasury/models/contact_detail_create_request.rb', line 29 def self.optionals %w[ contact_identifier contact_identifier_type ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
82 83 84 85 86 87 |
# File 'lib/modern_treasury/models/contact_detail_create_request.rb', line 82 def inspect class_name = self.class.name.split('::').last "<#{class_name} contact_identifier: #{@contact_identifier.inspect},"\ " contact_identifier_type: #{@contact_identifier_type.inspect}, additional_properties:"\ " #{@additional_properties}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
75 76 77 78 79 |
# File 'lib/modern_treasury/models/contact_detail_create_request.rb', line 75 def to_s class_name = self.class.name.split('::').last "<#{class_name} contact_identifier: #{@contact_identifier}, contact_identifier_type:"\ " #{@contact_identifier_type}, additional_properties: #{@additional_properties}>" end |