Class: ModernTreasury::InternalAccountController
- Inherits:
-
BaseController
- Object
- BaseController
- ModernTreasury::InternalAccountController
- Defined in:
- lib/modern_treasury/controllers/internal_account_controller.rb
Overview
InternalAccountController
Constant Summary
Constants inherited from BaseController
Instance Attribute Summary
Attributes inherited from BaseController
Instance Method Summary collapse
-
#create_internal_account(idempotency_key: nil, body: nil) ⇒ InternalAccount
TODO: type endpoint description here something unique, preferably something like an UUID.
-
#get_internal_account(id) ⇒ InternalAccount
TODO: type endpoint description here account.
-
#list_internal_accounts(per_page: nil, currency: nil, counterparty_id: nil, payment_type: nil, payment_direction: nil, metadata: nil, after_cursor: nil) ⇒ Array[InternalAccount]
TODO: type endpoint description here here with the internal account.
-
#update_internal_account(id, body: nil) ⇒ InternalAccount
TODO: type endpoint description here account.
Methods inherited from BaseController
#initialize, #new_parameter, #new_request_builder, #new_response_handler, user_agent
Constructor Details
This class inherits a constructor from ModernTreasury::BaseController
Instance Method Details
#create_internal_account(idempotency_key: nil, body: nil) ⇒ InternalAccount
TODO: type endpoint description here something unique, preferably something like an UUID. description here
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/modern_treasury/controllers/internal_account_controller.rb', line 60 def create_internal_account(idempotency_key: nil, body: nil) @api_call .request(new_request_builder(HttpMethodEnum::POST, '/api/internal_accounts', Server::DEFAULT) .header_param(new_parameter('application/json', key: 'Content-Type')) .header_param(new_parameter(idempotency_key, key: 'Idempotency-Key')) .body_param(new_parameter(body)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(Single.new('basic_auth'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(InternalAccount.method(:from_hash)) .local_error('404', 'not found', ErrorMessageException) .local_error('422', 'unsuccessful', ErrorMessageException)) .execute end |
#get_internal_account(id) ⇒ InternalAccount
TODO: type endpoint description here account.
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/modern_treasury/controllers/internal_account_controller.rb', line 88 def get_internal_account(id) @api_call .request(new_request_builder(HttpMethodEnum::GET, '/api/internal_accounts/{id}', Server::DEFAULT) .template_param(new_parameter(id, key: 'id') .should_encode(true)) .header_param(new_parameter('application/json', key: 'accept')) .auth(Single.new('basic_auth'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(InternalAccount.method(:from_hash)) .local_error('404', 'not found', ErrorMessageException)) .execute end |
#list_internal_accounts(per_page: nil, currency: nil, counterparty_id: nil, payment_type: nil, payment_direction: nil, metadata: nil, after_cursor: nil) ⇒ Array[InternalAccount]
TODO: type endpoint description here here with the internal account. associated with the internal account. payment that can be made by the internal account. direction of payments that can be made by internal account. you want to query for records with metadata key ‘Type` and value `Loan`, the query would be `metadata%5BType%5D=Loan`. This encodes the query parameters. here
27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/modern_treasury/controllers/internal_account_controller.rb', line 27 def list_internal_accounts(per_page: nil, currency: nil, counterparty_id: nil, payment_type: nil, payment_direction: nil, metadata: nil, after_cursor: nil) @api_call .request(new_request_builder(HttpMethodEnum::GET, '/api/internal_accounts', Server::DEFAULT) .query_param(new_parameter(per_page, key: 'per_page')) .query_param(new_parameter(currency, key: 'currency')) .query_param(new_parameter(counterparty_id, key: 'counterparty_id')) .query_param(new_parameter(payment_type, key: 'payment_type')) .query_param(new_parameter(payment_direction, key: 'payment_direction')) .query_param(new_parameter(, key: 'metadata')) .query_param(new_parameter(after_cursor, key: 'after_cursor')) .header_param(new_parameter('application/json', key: 'accept')) .auth(Single.new('basic_auth'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(InternalAccount.method(:from_hash)) .is_response_array(true)) .execute end |
#update_internal_account(id, body: nil) ⇒ InternalAccount
TODO: type endpoint description here account. description here
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/modern_treasury/controllers/internal_account_controller.rb', line 112 def update_internal_account(id, body: nil) @api_call .request(new_request_builder(HttpMethodEnum::PATCH, '/api/internal_accounts/{id}', Server::DEFAULT) .template_param(new_parameter(id, key: 'id') .should_encode(true)) .header_param(new_parameter('application/json', key: 'Content-Type')) .body_param(new_parameter(body)) .header_param(new_parameter('application/json', key: 'accept')) .body_serializer(proc do |param| param.to_json unless param.nil? end) .auth(Single.new('basic_auth'))) .response(new_response_handler .deserializer(APIHelper.method(:custom_type_deserializer)) .deserialize_into(InternalAccount.method(:from_hash)) .local_error('404', 'unsuccessful', ErrorMessageException)) .execute end |