Class: ModernTreasury::Ledger

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/modern_treasury/models/ledger.rb

Overview

Ledger Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(id = nil, object = nil, live_mode = nil, created_at = nil, updated_at = nil, discarded_at = nil, name = nil, description = nil, metadata = nil) ⇒ Ledger

Returns a new instance of Ledger.



82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/modern_treasury/models/ledger.rb', line 82

def initialize(id = nil, object = nil, live_mode = nil, created_at = nil,
               updated_at = nil, discarded_at = nil, name = nil,
               description = nil,  = nil)
  @id = id
  @object = object
  @live_mode = live_mode
  @created_at = created_at
  @updated_at = updated_at
  @discarded_at = discarded_at
  @name = name
  @description = description
  @metadata = 
end

Instance Attribute Details

#created_atDateTime

This field will be true if this object exists in the live environment or false if it exists in the test environment.

Returns:

  • (DateTime)


29
30
31
# File 'lib/modern_treasury/models/ledger.rb', line 29

def created_at
  @created_at
end

#descriptionString

An optional free-form description for internal use.

Returns:

  • (String)


47
48
49
# File 'lib/modern_treasury/models/ledger.rb', line 47

def description
  @description
end

#discarded_atDateTime

This field will be true if this object exists in the live environment or false if it exists in the test environment.

Returns:

  • (DateTime)


39
40
41
# File 'lib/modern_treasury/models/ledger.rb', line 39

def discarded_at
  @discarded_at
end

#idUUID | String

TODO: Write general description for this method

Returns:

  • (UUID | String)


15
16
17
# File 'lib/modern_treasury/models/ledger.rb', line 15

def id
  @id
end

#live_modeTrueClass | FalseClass

This field will be true if this object exists in the live environment or false if it exists in the test environment.

Returns:

  • (TrueClass | FalseClass)


24
25
26
# File 'lib/modern_treasury/models/ledger.rb', line 24

def live_mode
  @live_mode
end

#metadataHash[String, String]

Additional data represented as key-value pairs. Both the key and value must be strings.

Returns:

  • (Hash[String, String])


52
53
54
# File 'lib/modern_treasury/models/ledger.rb', line 52

def 
  @metadata
end

#nameString

The name of the ledger.

Returns:

  • (String)


43
44
45
# File 'lib/modern_treasury/models/ledger.rb', line 43

def name
  @name
end

#objectString

TODO: Write general description for this method

Returns:

  • (String)


19
20
21
# File 'lib/modern_treasury/models/ledger.rb', line 19

def object
  @object
end

#updated_atDateTime

This field will be true if this object exists in the live environment or false if it exists in the test environment.

Returns:

  • (DateTime)


34
35
36
# File 'lib/modern_treasury/models/ledger.rb', line 34

def updated_at
  @updated_at
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/modern_treasury/models/ledger.rb', line 97

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  id = hash.key?('id') ? hash['id'] : nil
  object = hash.key?('object') ? hash['object'] : nil
  live_mode = hash.key?('live_mode') ? hash['live_mode'] : nil
  created_at = if hash.key?('created_at')
                 (DateTimeHelper.from_rfc3339(hash['created_at']) if hash['created_at'])
               end
  updated_at = if hash.key?('updated_at')
                 (DateTimeHelper.from_rfc3339(hash['updated_at']) if hash['updated_at'])
               end
  discarded_at = if hash.key?('discarded_at')
                   (DateTimeHelper.from_rfc3339(hash['discarded_at']) if hash['discarded_at'])
                 end
  name = hash.key?('name') ? hash['name'] : nil
  description = hash.key?('description') ? hash['description'] : nil
   = hash.key?('metadata') ? hash['metadata'] : nil

  # Create object from extracted values.
  Ledger.new(id,
             object,
             live_mode,
             created_at,
             updated_at,
             discarded_at,
             name,
             description,
             )
end

.namesObject

A mapping from model property names to API property names.



55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/modern_treasury/models/ledger.rb', line 55

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['id'] = 'id'
  @_hash['object'] = 'object'
  @_hash['live_mode'] = 'live_mode'
  @_hash['created_at'] = 'created_at'
  @_hash['updated_at'] = 'updated_at'
  @_hash['discarded_at'] = 'discarded_at'
  @_hash['name'] = 'name'
  @_hash['description'] = 'description'
  @_hash['metadata'] = 'metadata'
  @_hash
end

.nullablesObject

An array for nullable fields



75
76
77
78
79
80
# File 'lib/modern_treasury/models/ledger.rb', line 75

def self.nullables
  %w[
    discarded_at
    description
  ]
end

.optionalsObject

An array for optional fields



70
71
72
# File 'lib/modern_treasury/models/ledger.rb', line 70

def self.optionals
  []
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



150
151
152
153
154
155
156
# File 'lib/modern_treasury/models/ledger.rb', line 150

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id.inspect}, object: #{@object.inspect}, live_mode:"\
  " #{@live_mode.inspect}, created_at: #{@created_at.inspect}, updated_at:"\
  " #{@updated_at.inspect}, discarded_at: #{@discarded_at.inspect}, name: #{@name.inspect},"\
  " description: #{@description.inspect}, metadata: #{@metadata.inspect}>"
end

#to_custom_created_atObject



129
130
131
# File 'lib/modern_treasury/models/ledger.rb', line 129

def to_custom_created_at
  DateTimeHelper.to_rfc3339(created_at)
end

#to_custom_discarded_atObject



137
138
139
# File 'lib/modern_treasury/models/ledger.rb', line 137

def to_custom_discarded_at
  DateTimeHelper.to_rfc3339(discarded_at)
end

#to_custom_updated_atObject



133
134
135
# File 'lib/modern_treasury/models/ledger.rb', line 133

def to_custom_updated_at
  DateTimeHelper.to_rfc3339(updated_at)
end

#to_sObject

Provides a human-readable string representation of the object.



142
143
144
145
146
147
# File 'lib/modern_treasury/models/ledger.rb', line 142

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} id: #{@id}, object: #{@object}, live_mode: #{@live_mode}, created_at:"\
  " #{@created_at}, updated_at: #{@updated_at}, discarded_at: #{@discarded_at}, name:"\
  " #{@name}, description: #{@description}, metadata: #{@metadata}>"
end