Class: ModernTreasury::LedgerAccountCategory
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ModernTreasury::LedgerAccountCategory
- Defined in:
- lib/modern_treasury/models/ledger_account_category.rb
Overview
LedgerAccountCategory Model.
Instance Attribute Summary collapse
-
#balances ⇒ LedgerBalances
The normal balance of the ledger account category.
-
#created_at ⇒ DateTime
This field will be true if this object exists in the live environment or false if it exists in the test environment.
-
#description ⇒ String
The description of the ledger account category.
-
#discarded_at ⇒ DateTime
This field will be true if this object exists in the live environment or false if it exists in the test environment.
-
#id ⇒ UUID | String
TODO: Write general description for this method.
-
#ledger_id ⇒ UUID | String
The id of the ledger that this account category belongs to.
-
#live_mode ⇒ TrueClass | FalseClass
This field will be true if this object exists in the live environment or false if it exists in the test environment.
-
#metadata ⇒ Hash[String, String]
Additional data represented as key-value pairs.
-
#name ⇒ String
The name of the ledger account category.
-
#normal_balance ⇒ NormalBalance2
The normal balance of the ledger account category.
-
#object ⇒ String
TODO: Write general description for this method.
-
#updated_at ⇒ DateTime
This field will be true if this object exists in the live environment or false if it exists in the test environment.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(id:, object:, live_mode:, created_at:, updated_at:, discarded_at:, name:, description:, metadata:, ledger_id:, normal_balance:, balances:) ⇒ LedgerAccountCategory
constructor
A new instance of LedgerAccountCategory.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_created_at ⇒ Object
- #to_custom_discarded_at ⇒ Object
- #to_custom_updated_at ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id:, object:, live_mode:, created_at:, updated_at:, discarded_at:, name:, description:, metadata:, ledger_id:, normal_balance:, balances:) ⇒ LedgerAccountCategory
Returns a new instance of LedgerAccountCategory.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/modern_treasury/models/ledger_account_category.rb', line 97 def initialize(id:, object:, live_mode:, created_at:, updated_at:, discarded_at:, name:, description:, metadata:, ledger_id:, normal_balance:, balances:) @id = id @object = object @live_mode = live_mode @created_at = created_at @updated_at = updated_at @discarded_at = discarded_at @name = name @description = description @metadata = @ledger_id = ledger_id @normal_balance = normal_balance @balances = balances end |
Instance Attribute Details
#balances ⇒ LedgerBalances
The normal balance of the ledger account category.
64 65 66 |
# File 'lib/modern_treasury/models/ledger_account_category.rb', line 64 def balances @balances end |
#created_at ⇒ DateTime
This field will be true if this object exists in the live environment or false if it exists in the test environment.
29 30 31 |
# File 'lib/modern_treasury/models/ledger_account_category.rb', line 29 def created_at @created_at end |
#description ⇒ String
The description of the ledger account category.
47 48 49 |
# File 'lib/modern_treasury/models/ledger_account_category.rb', line 47 def description @description end |
#discarded_at ⇒ DateTime
This field will be true if this object exists in the live environment or false if it exists in the test environment.
39 40 41 |
# File 'lib/modern_treasury/models/ledger_account_category.rb', line 39 def discarded_at @discarded_at end |
#id ⇒ UUID | String
TODO: Write general description for this method
15 16 17 |
# File 'lib/modern_treasury/models/ledger_account_category.rb', line 15 def id @id end |
#ledger_id ⇒ UUID | String
The id of the ledger that this account category belongs to.
56 57 58 |
# File 'lib/modern_treasury/models/ledger_account_category.rb', line 56 def ledger_id @ledger_id end |
#live_mode ⇒ TrueClass | FalseClass
This field will be true if this object exists in the live environment or false if it exists in the test environment.
24 25 26 |
# File 'lib/modern_treasury/models/ledger_account_category.rb', line 24 def live_mode @live_mode end |
#metadata ⇒ Hash[String, String]
Additional data represented as key-value pairs. Both the key and value must be strings.
52 53 54 |
# File 'lib/modern_treasury/models/ledger_account_category.rb', line 52 def @metadata end |
#name ⇒ String
The name of the ledger account category.
43 44 45 |
# File 'lib/modern_treasury/models/ledger_account_category.rb', line 43 def name @name end |
#normal_balance ⇒ NormalBalance2
The normal balance of the ledger account category.
60 61 62 |
# File 'lib/modern_treasury/models/ledger_account_category.rb', line 60 def normal_balance @normal_balance end |
#object ⇒ String
TODO: Write general description for this method
19 20 21 |
# File 'lib/modern_treasury/models/ledger_account_category.rb', line 19 def object @object end |
#updated_at ⇒ DateTime
This field will be true if this object exists in the live environment or false if it exists in the test environment.
34 35 36 |
# File 'lib/modern_treasury/models/ledger_account_category.rb', line 34 def updated_at @updated_at end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/modern_treasury/models/ledger_account_category.rb', line 115 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : nil object = hash.key?('object') ? hash['object'] : nil live_mode = hash.key?('live_mode') ? hash['live_mode'] : nil created_at = if hash.key?('created_at') (DateTimeHelper.from_rfc3339(hash['created_at']) if hash['created_at']) end updated_at = if hash.key?('updated_at') (DateTimeHelper.from_rfc3339(hash['updated_at']) if hash['updated_at']) end discarded_at = if hash.key?('discarded_at') (DateTimeHelper.from_rfc3339(hash['discarded_at']) if hash['discarded_at']) end name = hash.key?('name') ? hash['name'] : nil description = hash.key?('description') ? hash['description'] : nil = hash.key?('metadata') ? hash['metadata'] : nil ledger_id = hash.key?('ledger_id') ? hash['ledger_id'] : nil normal_balance = hash.key?('normal_balance') ? hash['normal_balance'] : nil balances = LedgerBalances.from_hash(hash['balances']) if hash['balances'] # Create object from extracted values. LedgerAccountCategory.new(id: id, object: object, live_mode: live_mode, created_at: created_at, updated_at: updated_at, discarded_at: discarded_at, name: name, description: description, metadata: , ledger_id: ledger_id, normal_balance: normal_balance, balances: balances) end |
.names ⇒ Object
A mapping from model property names to API property names.
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/modern_treasury/models/ledger_account_category.rb', line 67 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['object'] = 'object' @_hash['live_mode'] = 'live_mode' @_hash['created_at'] = 'created_at' @_hash['updated_at'] = 'updated_at' @_hash['discarded_at'] = 'discarded_at' @_hash['name'] = 'name' @_hash['description'] = 'description' @_hash['metadata'] = 'metadata' @_hash['ledger_id'] = 'ledger_id' @_hash['normal_balance'] = 'normal_balance' @_hash['balances'] = 'balances' @_hash end |
.nullables ⇒ Object
An array for nullable fields
90 91 92 93 94 95 |
# File 'lib/modern_treasury/models/ledger_account_category.rb', line 90 def self.nullables %w[ discarded_at description ] end |
.optionals ⇒ Object
An array for optional fields
85 86 87 |
# File 'lib/modern_treasury/models/ledger_account_category.rb', line 85 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
176 177 178 179 180 181 182 183 184 |
# File 'lib/modern_treasury/models/ledger_account_category.rb', line 176 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, object: #{@object.inspect}, live_mode:"\ " #{@live_mode.inspect}, created_at: #{@created_at.inspect}, updated_at:"\ " #{@updated_at.inspect}, discarded_at: #{@discarded_at.inspect}, name: #{@name.inspect},"\ " description: #{@description.inspect}, metadata: #{@metadata.inspect}, ledger_id:"\ " #{@ledger_id.inspect}, normal_balance: #{@normal_balance.inspect}, balances:"\ " #{@balances.inspect}>" end |
#to_custom_created_at ⇒ Object
154 155 156 |
# File 'lib/modern_treasury/models/ledger_account_category.rb', line 154 def to_custom_created_at DateTimeHelper.to_rfc3339(created_at) end |
#to_custom_discarded_at ⇒ Object
162 163 164 |
# File 'lib/modern_treasury/models/ledger_account_category.rb', line 162 def to_custom_discarded_at DateTimeHelper.to_rfc3339(discarded_at) end |
#to_custom_updated_at ⇒ Object
158 159 160 |
# File 'lib/modern_treasury/models/ledger_account_category.rb', line 158 def to_custom_updated_at DateTimeHelper.to_rfc3339(updated_at) end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
167 168 169 170 171 172 173 |
# File 'lib/modern_treasury/models/ledger_account_category.rb', line 167 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, object: #{@object}, live_mode: #{@live_mode}, created_at:"\ " #{@created_at}, updated_at: #{@updated_at}, discarded_at: #{@discarded_at}, name:"\ " #{@name}, description: #{@description}, metadata: #{@metadata}, ledger_id: #{@ledger_id},"\ " normal_balance: #{@normal_balance}, balances: #{@balances}>" end |