Class: ModernTreasury::LedgerEventHandler
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ModernTreasury::LedgerEventHandler
- Defined in:
- lib/modern_treasury/models/ledger_event_handler.rb
Overview
LedgerEventHandler Model.
Instance Attribute Summary collapse
-
#conditions ⇒ LedgerEventHandlerConditions
An optional description.
-
#created_at ⇒ DateTime
This field will be true if this object exists in the live environment or false if it exists in the test environment.
-
#description ⇒ String
An optional description.
-
#discarded_at ⇒ DateTime
This field will be true if this object exists in the live environment or false if it exists in the test environment.
-
#id ⇒ UUID | String
TODO: Write general description for this method.
-
#ledger_transaction_template ⇒ LedgerEventHandlerLedgerTransactionTemplate
An optional description.
-
#live_mode ⇒ TrueClass | FalseClass
This field will be true if this object exists in the live environment or false if it exists in the test environment.
-
#metadata ⇒ Hash[String, String]
Additional data represented as key-value pairs.
-
#name ⇒ String
Name of the ledger event handler.
-
#object ⇒ String
TODO: Write general description for this method.
-
#updated_at ⇒ DateTime
This field will be true if this object exists in the live environment or false if it exists in the test environment.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(id:, object:, live_mode:, created_at:, updated_at:, discarded_at:, name:, description:, ledger_transaction_template:, conditions:, metadata:) ⇒ LedgerEventHandler
constructor
A new instance of LedgerEventHandler.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
- #to_custom_created_at ⇒ Object
- #to_custom_discarded_at ⇒ Object
- #to_custom_updated_at ⇒ Object
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(id:, object:, live_mode:, created_at:, updated_at:, discarded_at:, name:, description:, ledger_transaction_template:, conditions:, metadata:) ⇒ LedgerEventHandler
Returns a new instance of LedgerEventHandler.
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/modern_treasury/models/ledger_event_handler.rb', line 93 def initialize(id:, object:, live_mode:, created_at:, updated_at:, discarded_at:, name:, description:, ledger_transaction_template:, conditions:, metadata:) @id = id @object = object @live_mode = live_mode @created_at = created_at @updated_at = updated_at @discarded_at = discarded_at @name = name @description = description @ledger_transaction_template = ledger_transaction_template @conditions = conditions @metadata = end |
Instance Attribute Details
#conditions ⇒ LedgerEventHandlerConditions
An optional description.
55 56 57 |
# File 'lib/modern_treasury/models/ledger_event_handler.rb', line 55 def conditions @conditions end |
#created_at ⇒ DateTime
This field will be true if this object exists in the live environment or false if it exists in the test environment.
29 30 31 |
# File 'lib/modern_treasury/models/ledger_event_handler.rb', line 29 def created_at @created_at end |
#description ⇒ String
An optional description.
47 48 49 |
# File 'lib/modern_treasury/models/ledger_event_handler.rb', line 47 def description @description end |
#discarded_at ⇒ DateTime
This field will be true if this object exists in the live environment or false if it exists in the test environment.
39 40 41 |
# File 'lib/modern_treasury/models/ledger_event_handler.rb', line 39 def discarded_at @discarded_at end |
#id ⇒ UUID | String
TODO: Write general description for this method
15 16 17 |
# File 'lib/modern_treasury/models/ledger_event_handler.rb', line 15 def id @id end |
#ledger_transaction_template ⇒ LedgerEventHandlerLedgerTransactionTemplate
An optional description.
51 52 53 |
# File 'lib/modern_treasury/models/ledger_event_handler.rb', line 51 def ledger_transaction_template @ledger_transaction_template end |
#live_mode ⇒ TrueClass | FalseClass
This field will be true if this object exists in the live environment or false if it exists in the test environment.
24 25 26 |
# File 'lib/modern_treasury/models/ledger_event_handler.rb', line 24 def live_mode @live_mode end |
#metadata ⇒ Hash[String, String]
Additional data represented as key-value pairs. Both the key and value must be strings.
60 61 62 |
# File 'lib/modern_treasury/models/ledger_event_handler.rb', line 60 def @metadata end |
#name ⇒ String
Name of the ledger event handler.
43 44 45 |
# File 'lib/modern_treasury/models/ledger_event_handler.rb', line 43 def name @name end |
#object ⇒ String
TODO: Write general description for this method
19 20 21 |
# File 'lib/modern_treasury/models/ledger_event_handler.rb', line 19 def object @object end |
#updated_at ⇒ DateTime
This field will be true if this object exists in the live environment or false if it exists in the test environment.
34 35 36 |
# File 'lib/modern_treasury/models/ledger_event_handler.rb', line 34 def updated_at @updated_at end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/modern_treasury/models/ledger_event_handler.rb', line 110 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. id = hash.key?('id') ? hash['id'] : nil object = hash.key?('object') ? hash['object'] : nil live_mode = hash.key?('live_mode') ? hash['live_mode'] : nil created_at = if hash.key?('created_at') (DateTimeHelper.from_rfc3339(hash['created_at']) if hash['created_at']) end updated_at = if hash.key?('updated_at') (DateTimeHelper.from_rfc3339(hash['updated_at']) if hash['updated_at']) end discarded_at = if hash.key?('discarded_at') (DateTimeHelper.from_rfc3339(hash['discarded_at']) if hash['discarded_at']) end name = hash.key?('name') ? hash['name'] : nil description = hash.key?('description') ? hash['description'] : nil if hash['ledger_transaction_template'] ledger_transaction_template = LedgerEventHandlerLedgerTransactionTemplate.from_hash(hash['ledger_transaction_template']) end conditions = LedgerEventHandlerConditions.from_hash(hash['conditions']) if hash['conditions'] = hash.key?('metadata') ? hash['metadata'] : nil # Create object from extracted values. LedgerEventHandler.new(id: id, object: object, live_mode: live_mode, created_at: created_at, updated_at: updated_at, discarded_at: discarded_at, name: name, description: description, ledger_transaction_template: ledger_transaction_template, conditions: conditions, metadata: ) end |
.names ⇒ Object
A mapping from model property names to API property names.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/modern_treasury/models/ledger_event_handler.rb', line 63 def self.names @_hash = {} if @_hash.nil? @_hash['id'] = 'id' @_hash['object'] = 'object' @_hash['live_mode'] = 'live_mode' @_hash['created_at'] = 'created_at' @_hash['updated_at'] = 'updated_at' @_hash['discarded_at'] = 'discarded_at' @_hash['name'] = 'name' @_hash['description'] = 'description' @_hash['ledger_transaction_template'] = 'ledger_transaction_template' @_hash['conditions'] = 'conditions' @_hash['metadata'] = 'metadata' @_hash end |
.nullables ⇒ Object
An array for nullable fields
85 86 87 88 89 90 91 |
# File 'lib/modern_treasury/models/ledger_event_handler.rb', line 85 def self.nullables %w[ discarded_at description metadata ] end |
.optionals ⇒ Object
An array for optional fields
80 81 82 |
# File 'lib/modern_treasury/models/ledger_event_handler.rb', line 80 def self.optionals [] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
171 172 173 174 175 176 177 178 179 |
# File 'lib/modern_treasury/models/ledger_event_handler.rb', line 171 def inspect class_name = self.class.name.split('::').last "<#{class_name} id: #{@id.inspect}, object: #{@object.inspect}, live_mode:"\ " #{@live_mode.inspect}, created_at: #{@created_at.inspect}, updated_at:"\ " #{@updated_at.inspect}, discarded_at: #{@discarded_at.inspect}, name: #{@name.inspect},"\ " description: #{@description.inspect}, ledger_transaction_template:"\ " #{@ledger_transaction_template.inspect}, conditions: #{@conditions.inspect}, metadata:"\ " #{@metadata.inspect}>" end |
#to_custom_created_at ⇒ Object
149 150 151 |
# File 'lib/modern_treasury/models/ledger_event_handler.rb', line 149 def to_custom_created_at DateTimeHelper.to_rfc3339(created_at) end |
#to_custom_discarded_at ⇒ Object
157 158 159 |
# File 'lib/modern_treasury/models/ledger_event_handler.rb', line 157 def to_custom_discarded_at DateTimeHelper.to_rfc3339(discarded_at) end |
#to_custom_updated_at ⇒ Object
153 154 155 |
# File 'lib/modern_treasury/models/ledger_event_handler.rb', line 153 def to_custom_updated_at DateTimeHelper.to_rfc3339(updated_at) end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
162 163 164 165 166 167 168 |
# File 'lib/modern_treasury/models/ledger_event_handler.rb', line 162 def to_s class_name = self.class.name.split('::').last "<#{class_name} id: #{@id}, object: #{@object}, live_mode: #{@live_mode}, created_at:"\ " #{@created_at}, updated_at: #{@updated_at}, discarded_at: #{@discarded_at}, name:"\ " #{@name}, description: #{@description}, ledger_transaction_template:"\ " #{@ledger_transaction_template}, conditions: #{@conditions}, metadata: #{@metadata}>" end |