Class: ModernTreasury::ReturnCreateRequest
- Inherits:
-
BaseModel
- Object
- CoreLibrary::BaseModel
- BaseModel
- ModernTreasury::ReturnCreateRequest
- Defined in:
- lib/modern_treasury/models/return_create_request.rb
Overview
ReturnCreateRequest Model.
Instance Attribute Summary collapse
-
#additional_information ⇒ String
Some returns may include additional information from the bank.
-
#code ⇒ Code1Enum
The return code.
-
#date_of_death ⇒ Date
If the return code is ‘R14` or `R15` this is the date the deceased counterparty passed away.
-
#reason ⇒ String
An optional description of the reason for the return.
-
#returnable_id ⇒ UUID | String
The ID of the object being returned or ‘null`.
-
#returnable_type ⇒ String
readonly
The type of object being returned.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(returnable_id = nil, code = SKIP, reason = SKIP, date_of_death = SKIP, additional_information = SKIP) ⇒ ReturnCreateRequest
constructor
A new instance of ReturnCreateRequest.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(returnable_id = nil, code = SKIP, reason = SKIP, date_of_death = SKIP, additional_information = SKIP) ⇒ ReturnCreateRequest
Returns a new instance of ReturnCreateRequest.
73 74 75 76 77 78 79 80 81 |
# File 'lib/modern_treasury/models/return_create_request.rb', line 73 def initialize(returnable_id = nil, code = SKIP, reason = SKIP, date_of_death = SKIP, additional_information = SKIP) @returnable_id = returnable_id @code = code unless code == SKIP @reason = reason unless reason == SKIP @date_of_death = date_of_death unless date_of_death == SKIP @additional_information = additional_information unless additional_information == SKIP @returnable_type = 'incoming_payment_detail' end |
Instance Attribute Details
#additional_information ⇒ String
Some returns may include additional information from the bank. In these cases, this string will be present.
33 34 35 |
# File 'lib/modern_treasury/models/return_create_request.rb', line 33 def additional_information @additional_information end |
#code ⇒ Code1Enum
The return code. For ACH returns, this is the required ACH return code.
18 19 20 |
# File 'lib/modern_treasury/models/return_create_request.rb', line 18 def code @code end |
#date_of_death ⇒ Date
If the return code is ‘R14` or `R15` this is the date the deceased counterparty passed away.
28 29 30 |
# File 'lib/modern_treasury/models/return_create_request.rb', line 28 def date_of_death @date_of_death end |
#reason ⇒ String
An optional description of the reason for the return. This is for internal usage and will not be transmitted to the bank.”
23 24 25 |
# File 'lib/modern_treasury/models/return_create_request.rb', line 23 def reason @reason end |
#returnable_id ⇒ UUID | String
The ID of the object being returned or ‘null`.
14 15 16 |
# File 'lib/modern_treasury/models/return_create_request.rb', line 14 def returnable_id @returnable_id end |
#returnable_type ⇒ String (readonly)
The type of object being returned. Currently, this may only be incoming_payment_detail.
38 39 40 |
# File 'lib/modern_treasury/models/return_create_request.rb', line 38 def returnable_type @returnable_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/modern_treasury/models/return_create_request.rb', line 84 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. returnable_id = hash.key?('returnable_id') ? hash['returnable_id'] : nil code = hash.key?('code') ? hash['code'] : SKIP reason = hash.key?('reason') ? hash['reason'] : SKIP date_of_death = hash.key?('date_of_death') ? hash['date_of_death'] : SKIP additional_information = hash.key?('additional_information') ? hash['additional_information'] : SKIP # Create object from extracted values. ReturnCreateRequest.new(returnable_id, code, reason, date_of_death, additional_information) end |
.names ⇒ Object
A mapping from model property names to API property names.
41 42 43 44 45 46 47 48 49 50 |
# File 'lib/modern_treasury/models/return_create_request.rb', line 41 def self.names @_hash = {} if @_hash.nil? @_hash['returnable_id'] = 'returnable_id' @_hash['code'] = 'code' @_hash['reason'] = 'reason' @_hash['date_of_death'] = 'date_of_death' @_hash['additional_information'] = 'additional_information' @_hash['returnable_type'] = 'returnable_type' @_hash end |
.nullables ⇒ Object
An array for nullable fields
63 64 65 66 67 68 69 70 71 |
# File 'lib/modern_treasury/models/return_create_request.rb', line 63 def self.nullables %w[ returnable_id code reason date_of_death additional_information ] end |
.optionals ⇒ Object
An array for optional fields
53 54 55 56 57 58 59 60 |
# File 'lib/modern_treasury/models/return_create_request.rb', line 53 def self.optionals %w[ code reason date_of_death additional_information ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
112 113 114 115 116 117 |
# File 'lib/modern_treasury/models/return_create_request.rb', line 112 def inspect class_name = self.class.name.split('::').last "<#{class_name} returnable_id: #{@returnable_id.inspect}, code: #{@code.inspect}, reason:"\ " #{@reason.inspect}, date_of_death: #{@date_of_death.inspect}, additional_information:"\ " #{@additional_information.inspect}, returnable_type: #{@returnable_type.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
104 105 106 107 108 109 |
# File 'lib/modern_treasury/models/return_create_request.rb', line 104 def to_s class_name = self.class.name.split('::').last "<#{class_name} returnable_id: #{@returnable_id}, code: #{@code}, reason: #{@reason},"\ " date_of_death: #{@date_of_death}, additional_information: #{@additional_information},"\ " returnable_type: #{@returnable_type}>" end |