Class: ModernTreasury::RoutingDetail1

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/modern_treasury/models/routing_detail1.rb

Overview

RoutingDetail1 Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(routing_number:, routing_number_type:, payment_type: SKIP, additional_properties: nil) ⇒ RoutingDetail1

Returns a new instance of RoutingDetail1.



45
46
47
48
49
50
51
52
53
54
# File 'lib/modern_treasury/models/routing_detail1.rb', line 45

def initialize(routing_number:, routing_number_type:, payment_type: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @routing_number = routing_number
  @routing_number_type = routing_number_type
  @payment_type = payment_type unless payment_type == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#payment_typePaymentType2

TODO: Write general description for this method

Returns:



22
23
24
# File 'lib/modern_treasury/models/routing_detail1.rb', line 22

def payment_type
  @payment_type
end

#routing_numberString

TODO: Write general description for this method

Returns:

  • (String)


14
15
16
# File 'lib/modern_treasury/models/routing_detail1.rb', line 14

def routing_number
  @routing_number
end

#routing_number_typeRoutingNumberType1

TODO: Write general description for this method

Returns:



18
19
20
# File 'lib/modern_treasury/models/routing_detail1.rb', line 18

def routing_number_type
  @routing_number_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/modern_treasury/models/routing_detail1.rb', line 57

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  routing_number =
    hash.key?('routing_number') ? hash['routing_number'] : nil
  routing_number_type =
    hash.key?('routing_number_type') ? hash['routing_number_type'] : nil
  payment_type = hash.key?('payment_type') ? hash['payment_type'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  RoutingDetail1.new(routing_number: routing_number,
                     routing_number_type: routing_number_type,
                     payment_type: payment_type,
                     additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



25
26
27
28
29
30
31
# File 'lib/modern_treasury/models/routing_detail1.rb', line 25

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['routing_number'] = 'routing_number'
  @_hash['routing_number_type'] = 'routing_number_type'
  @_hash['payment_type'] = 'payment_type'
  @_hash
end

.nullablesObject

An array for nullable fields



41
42
43
# File 'lib/modern_treasury/models/routing_detail1.rb', line 41

def self.nullables
  []
end

.optionalsObject

An array for optional fields



34
35
36
37
38
# File 'lib/modern_treasury/models/routing_detail1.rb', line 34

def self.optionals
  %w[
    payment_type
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



90
91
92
93
94
95
# File 'lib/modern_treasury/models/routing_detail1.rb', line 90

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} routing_number: #{@routing_number.inspect}, routing_number_type:"\
  " #{@routing_number_type.inspect}, payment_type: #{@payment_type.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



82
83
84
85
86
87
# File 'lib/modern_treasury/models/routing_detail1.rb', line 82

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} routing_number: #{@routing_number}, routing_number_type:"\
  " #{@routing_number_type}, payment_type: #{@payment_type}, additional_properties:"\
  " #{@additional_properties}>"
end