Class: ModernTreasury::RoutingDetail1
- Defined in:
- lib/modern_treasury/models/routing_detail1.rb
Overview
RoutingDetail1 Model.
Instance Attribute Summary collapse
-
#payment_type ⇒ PaymentType2Enum
TODO: Write general description for this method.
-
#routing_number ⇒ String
TODO: Write general description for this method.
-
#routing_number_type ⇒ RoutingNumberType1Enum
TODO: Write general description for this method.
Class Method Summary collapse
-
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
-
.names ⇒ Object
A mapping from model property names to API property names.
-
.nullables ⇒ Object
An array for nullable fields.
-
.optionals ⇒ Object
An array for optional fields.
Instance Method Summary collapse
-
#initialize(routing_number = nil, routing_number_type = nil, payment_type = SKIP) ⇒ RoutingDetail1
constructor
A new instance of RoutingDetail1.
-
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
-
#to_s ⇒ Object
Provides a human-readable string representation of the object.
Methods inherited from BaseModel
#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json
Constructor Details
#initialize(routing_number = nil, routing_number_type = nil, payment_type = SKIP) ⇒ RoutingDetail1
Returns a new instance of RoutingDetail1.
45 46 47 48 49 50 |
# File 'lib/modern_treasury/models/routing_detail1.rb', line 45 def initialize(routing_number = nil, routing_number_type = nil, payment_type = SKIP) @routing_number = routing_number @routing_number_type = routing_number_type @payment_type = payment_type unless payment_type == SKIP end |
Instance Attribute Details
#payment_type ⇒ PaymentType2Enum
TODO: Write general description for this method
22 23 24 |
# File 'lib/modern_treasury/models/routing_detail1.rb', line 22 def payment_type @payment_type end |
#routing_number ⇒ String
TODO: Write general description for this method
14 15 16 |
# File 'lib/modern_treasury/models/routing_detail1.rb', line 14 def routing_number @routing_number end |
#routing_number_type ⇒ RoutingNumberType1Enum
TODO: Write general description for this method
18 19 20 |
# File 'lib/modern_treasury/models/routing_detail1.rb', line 18 def routing_number_type @routing_number_type end |
Class Method Details
.from_hash(hash) ⇒ Object
Creates an instance of the object from a hash.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 |
# File 'lib/modern_treasury/models/routing_detail1.rb', line 53 def self.from_hash(hash) return nil unless hash # Extract variables from the hash. routing_number = hash.key?('routing_number') ? hash['routing_number'] : nil routing_number_type = hash.key?('routing_number_type') ? hash['routing_number_type'] : nil payment_type = hash.key?('payment_type') ? hash['payment_type'] : SKIP # Create object from extracted values. RoutingDetail1.new(routing_number, routing_number_type, payment_type) end |
.names ⇒ Object
A mapping from model property names to API property names.
25 26 27 28 29 30 31 |
# File 'lib/modern_treasury/models/routing_detail1.rb', line 25 def self.names @_hash = {} if @_hash.nil? @_hash['routing_number'] = 'routing_number' @_hash['routing_number_type'] = 'routing_number_type' @_hash['payment_type'] = 'payment_type' @_hash end |
.nullables ⇒ Object
An array for nullable fields
41 42 43 |
# File 'lib/modern_treasury/models/routing_detail1.rb', line 41 def self.nullables [] end |
.optionals ⇒ Object
An array for optional fields
34 35 36 37 38 |
# File 'lib/modern_treasury/models/routing_detail1.rb', line 34 def self.optionals %w[ payment_type ] end |
Instance Method Details
#inspect ⇒ Object
Provides a debugging-friendly string with detailed object information.
77 78 79 80 81 |
# File 'lib/modern_treasury/models/routing_detail1.rb', line 77 def inspect class_name = self.class.name.split('::').last "<#{class_name} routing_number: #{@routing_number.inspect}, routing_number_type:"\ " #{@routing_number_type.inspect}, payment_type: #{@payment_type.inspect}>" end |
#to_s ⇒ Object
Provides a human-readable string representation of the object.
70 71 72 73 74 |
# File 'lib/modern_treasury/models/routing_detail1.rb', line 70 def to_s class_name = self.class.name.split('::').last "<#{class_name} routing_number: #{@routing_number}, routing_number_type:"\ " #{@routing_number_type}, payment_type: #{@payment_type}>" end |