Class: ModernTreasury::RoutingDetailCreateRequest

Inherits:
BaseModel
  • Object
show all
Defined in:
lib/modern_treasury/models/routing_detail_create_request.rb

Overview

RoutingDetailCreateRequest Model.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from BaseModel

#check_for_conflict, #process_additional_properties, #process_array, #process_basic_value, #process_hash, #to_hash, #to_json

Constructor Details

#initialize(routing_number:, routing_number_type:, payment_type: SKIP, additional_properties: nil) ⇒ RoutingDetailCreateRequest

Returns a new instance of RoutingDetailCreateRequest.



49
50
51
52
53
54
55
56
57
58
# File 'lib/modern_treasury/models/routing_detail_create_request.rb', line 49

def initialize(routing_number:, routing_number_type:, payment_type: SKIP,
               additional_properties: nil)
  # Add additional model properties to the instance
  additional_properties = {} if additional_properties.nil?

  @routing_number = routing_number
  @routing_number_type = routing_number_type
  @payment_type = payment_type unless payment_type == SKIP
  @additional_properties = additional_properties
end

Instance Attribute Details

#payment_typePaymentType1

If the routing detail is to be used for a specific payment type this field will be populated, otherwise null.

Returns:



24
25
26
# File 'lib/modern_treasury/models/routing_detail_create_request.rb', line 24

def payment_type
  @payment_type
end

#routing_numberString

The routing number of the bank.

Returns:

  • (String)


14
15
16
# File 'lib/modern_treasury/models/routing_detail_create_request.rb', line 14

def routing_number
  @routing_number
end

#routing_number_typeRoutingNumberType

One of ‘aba`, `swift`, `ca_cpa`, `au_bsb`, `gb_sort_code`, `in_ifsc`, `cnaps`.

Returns:



19
20
21
# File 'lib/modern_treasury/models/routing_detail_create_request.rb', line 19

def routing_number_type
  @routing_number_type
end

Class Method Details

.from_hash(hash) ⇒ Object

Creates an instance of the object from a hash.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/modern_treasury/models/routing_detail_create_request.rb', line 61

def self.from_hash(hash)
  return nil unless hash

  # Extract variables from the hash.
  routing_number =
    hash.key?('routing_number') ? hash['routing_number'] : nil
  routing_number_type =
    hash.key?('routing_number_type') ? hash['routing_number_type'] : nil
  payment_type = hash.key?('payment_type') ? hash['payment_type'] : SKIP

  # Create a new hash for additional properties, removing known properties.
  new_hash = hash.reject { |k, _| names.value?(k) }

  additional_properties = APIHelper.get_additional_properties(
    new_hash, proc { |value| value }
  )

  # Create object from extracted values.
  RoutingDetailCreateRequest.new(routing_number: routing_number,
                                 routing_number_type: routing_number_type,
                                 payment_type: payment_type,
                                 additional_properties: additional_properties)
end

.namesObject

A mapping from model property names to API property names.



27
28
29
30
31
32
33
# File 'lib/modern_treasury/models/routing_detail_create_request.rb', line 27

def self.names
  @_hash = {} if @_hash.nil?
  @_hash['routing_number'] = 'routing_number'
  @_hash['routing_number_type'] = 'routing_number_type'
  @_hash['payment_type'] = 'payment_type'
  @_hash
end

.nullablesObject

An array for nullable fields



43
44
45
46
47
# File 'lib/modern_treasury/models/routing_detail_create_request.rb', line 43

def self.nullables
  %w[
    payment_type
  ]
end

.optionalsObject

An array for optional fields



36
37
38
39
40
# File 'lib/modern_treasury/models/routing_detail_create_request.rb', line 36

def self.optionals
  %w[
    payment_type
  ]
end

Instance Method Details

#inspectObject

Provides a debugging-friendly string with detailed object information.



94
95
96
97
98
99
# File 'lib/modern_treasury/models/routing_detail_create_request.rb', line 94

def inspect
  class_name = self.class.name.split('::').last
  "<#{class_name} routing_number: #{@routing_number.inspect}, routing_number_type:"\
  " #{@routing_number_type.inspect}, payment_type: #{@payment_type.inspect},"\
  " additional_properties: #{@additional_properties}>"
end

#to_sObject

Provides a human-readable string representation of the object.



86
87
88
89
90
91
# File 'lib/modern_treasury/models/routing_detail_create_request.rb', line 86

def to_s
  class_name = self.class.name.split('::').last
  "<#{class_name} routing_number: #{@routing_number}, routing_number_type:"\
  " #{@routing_number_type}, payment_type: #{@payment_type}, additional_properties:"\
  " #{@additional_properties}>"
end